#
# spec file for package gimp
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global abiver 4
%global apiver 2.0
%global gegl_version 0.4.38

%if 0%{?suse_version} >= 1550
%bcond_without libheif
%else
%bcond_with    libheif
%endif

%if 0%{?sle_version}
%bcond_with python_plugin
%else
%bcond_without python_plugin
%endif
Name:           gimp
Version:        2.10.38
Release:        2.1
Summary:        The GNU Image Manipulation Program
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Bitmap Editors
URL:            https://www.gimp.org/
Source:         https://download.gimp.org/pub/gimp/v2.10/%{name}-%{version}.tar.bz2
Source1:        macros.gimp
# openSUSE palette file
Source2:        openSUSE.gpl
# PATCH-FIX-UPSTREAM fix-gcc14-build.patch bsc#1223892
Patch0:         fix-gcc14-build.patch

BuildRequires:  aalib-devel
BuildRequires:  alsa-devel >= 1.0.0
BuildRequires:  fdupes
BuildRequires:  fontconfig-devel >= 2.12.4
BuildRequires:  gcc-c++
BuildRequires:  gdk-pixbuf-loader-rsvg
# For some odd reason build needs gegl executable.
BuildRequires:  gegl >= %{gegl_version}
BuildRequires:  ghostscript-devel
# Explicitly needed, otherwise ghostscript-mini is used during the
# build, and it's not enough for gimp.
BuildRequires:  ghostscript-library
BuildRequires:  glib-networking
BuildRequires:  intltool >= 0.40.1
BuildRequires:  libtiff-devel
BuildRequires:  libwmf-devel >= 0.2.8
BuildRequires:  libxslt-tools
BuildRequires:  libjxl-devel >= 0.7.0
BuildRequires:  pkgconfig
%if %{with python_plugin}
BuildRequires:  python-gtk-devel >= 2.10.4
%endif
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(atk) >= 2.2.0
BuildRequires:  (pkgconfig(babl) or pkgconfig(babl-0.1))
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(cairo) >= 1.12.2
BuildRequires:  pkgconfig(cairo-pdf) >= 1.12.2
BuildRequires:  pkgconfig(dbus-glib-1) >= 0.70
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.30.8
BuildRequires:  pkgconfig(gegl-0.4) >= %{gegl_version}
BuildRequires:  pkgconfig(gexiv2) >= 0.10.6
BuildRequires:  pkgconfig(glib-2.0) >= 2.56.2
BuildRequires:  pkgconfig(gtk+-2.0) >= 2.24.32
BuildRequires:  pkgconfig(gudev-1.0) >= 167
BuildRequires:  pkgconfig(harfbuzz) >= 0.9.19
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(json-glib-1.0) >= 1.2.6
BuildRequires:  pkgconfig(lcms2) >= 2.8
BuildRequires:  pkgconfig(libexif) >= 0.6.15
%if %{with libheif}
BuildRequires:  pkgconfig(libheif) >= 1.3.2
%endif
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(liblzma) >= 5.0.0
BuildRequires:  pkgconfig(libmng)
BuildRequires:  pkgconfig(libmypaint) >= 1.3.0
BuildRequires:  pkgconfig(libopenjp2) >= 2.1.0
BuildRequires:  pkgconfig(libpng) >= 1.6.25
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.40.6
BuildRequires:  pkgconfig(libunwind)
BuildRequires:  pkgconfig(libwebp) >= 0.6.0
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(mypaint-brushes-1.0)
BuildRequires:  pkgconfig(OpenEXR) >= 1.6.1
BuildRequires:  pkgconfig(pango) >= 1.29.4
BuildRequires:  pkgconfig(poppler-data) >= 0.4.7
BuildRequires:  pkgconfig(poppler-glib) >= 0.44.0
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  xdg-utils
# obs does not automaticaly add this
Requires:       libglib-2_0-0 >= 2.54.2
Requires:       libgexiv2-2 >= 0.10.6
Requires:       libbabl-0_1-0 >= 0.1.78
# Explicitly declare the libgimp versions for upgrade purposes
Requires:       libgimp-2_0-0 = %{version}
Requires:       libgimpui-2_0-0 = %{version}
Requires:       xdg-utils
Recommends:     iso-codes
Suggests:       AdobeICCProfiles
Suggests:       gimp-2.0-scanner-plugin
Obsoletes:      %{name}-help-browser
Provides:       gimp-2.0 = %{version}
Provides:       gimp(abi) = %{abiver}
Provides:       gimp(api) = %{apiver}

%description
The GIMP is an image composition and editing program, which can be
used for creating logos and other graphics for Web pages. The GIMP
offers many tools and filters, and provides a large image
manipulation toolbox, including channel operations and layers,
effects, subpixel imaging and antialiasing, and conversions, together
with multilevel undo. The GIMP offers a scripting facility, but many
of the included scripts rely on fonts that we cannot distribute.

%package -n libgimp-2_0-0
Summary:        The GNU Image Manipulation Program - Libraries
Group:          System/Libraries
%requires_ge    libbabl-0_1-0
%requires_ge    libgegl-0_4-0

%description -n libgimp-2_0-0
The GIMP is an image composition and editing program. GIMP offers
many tools and filters, and provides a large image manipulation
toolbox and scripting.

This package provides GIMP libraries.

%package -n libgimpui-2_0-0
Summary:        The GNU Image Manipulation Program - UI Libraries
Group:          System/Libraries

%description -n libgimpui-2_0-0
The GIMP is an image composition and editing program. GIMP offers
many tools and filters, and provides a large image manipulation
toolbox and scripting.

This package provides GIMP UI libraries.

%if %{with python_plugin}
%package plugins-python
Summary:        The GNU Image Manipulation Program - python-gtk based plugins
Group:          Productivity/Graphics/Bitmap Editors
Requires:       %{name} = %{version}
Requires:       python-gtk
Recommends:     python-xml
Provides:       gimp-2.0-plugins-python = %{version}
Obsoletes:      gimp-unstable-plugins-python < 2.6.0
# For update from <= 10.3 and SLED 10:
Provides:       %{name}:%{_libdir}/gimp/2.0/plug-ins/pyconsole.py = %{version}

%description plugins-python
The GIMP is an image composition and editing program. GIMP offers
many tools and filters, and provides a large image manipulation
toolbox and scripting.
%endif

%package plugin-aa
Summary:        The GNU Image Manipulation Program -- ASCII-Art output plugin
Group:          Productivity/Graphics/Bitmap Editors
Requires:       %{name} = %{version}
# Let's trigger automatic installation if the user already has libaa installed.
Supplements:    packageand(%{name}:libaa1)

%description plugin-aa
The GIMP is an image composition and editing program. GIMP offers
many tools and filters, and provides a large image manipulation
toolbox and scripting.

%package devel
Summary:        The GNU Image Manipulation Program
Group:          Development/Libraries/Other
Requires:       libgimp-2_0-0 = %{version}
Requires:       libgimpui-2_0-0 = %{version}
Provides:       gimp-2.0-devel = %{version}
Provides:       gimp-doc = 2.6.4
Obsoletes:      gimp-doc < 2.6.4
Obsoletes:      gimp-unstable-devel < 2.6.0

%description devel
The GIMP is an image composition and editing program. GIMP offers
many tools and filters, and provides a large image manipulation
toolbox and scripting.

This subpackage contains libraries and header files for developing
applications that want to make use of the GIMP libraries.

%lang_package

%prep
%autosetup -p1

export LC_ALL=en_US.UTF-8
export LANG=en_US.UTF-8
# Safety check for ABI version change.
vabi=`printf "%d" $(sed -n '/#define GIMP_MODULE_ABI_VERSION/{s/.* //;p}' libgimpmodule/gimpmodule.h)`
if test "x${vabi}" != "x%{abiver}"; then
   : Error: Upstream ABI version is now ${vabi}, expecting %{abiver}.
   : Update the apiver macro and rebuild.
   exit 1
fi
# Safety check for API version change.
vapi=`sed -n '/#define GIMP_API_VERSION/{s/.* //;p}' libgimpbase/gimpversion.h | sed -e 's@"@@g'`
if test "x${vapi}" != "x%{apiver}"; then
   : Error: Upstream API version is now ${vapi}, expecting %{apiver}.
   : Update the apiver macro and rebuild.
   exit 1
fi

%build
export LC_ALL=en_US.UTF-8
export LANG=en_US.UTF-8
export CFLAGS="%{optflags} -fno-strict-aliasing"
%configure \
	--disable-silent-rules \
	--disable-static\
	--without-webkit\
	--with-lcms=lcms2\
        %{!?with_python_plugin:--disable-python} \
	--libexecdir=%{_libexecdir}\
	--enable-default-binary\
	--disable-check-update\
	--enable-mp

%make_build

%install
%make_install
install -D -m 0644 %{SOURCE2} %{buildroot}%{_datadir}/gimp/2.0/palettes
%suse_update_desktop_file -N GIMP gimp
rm %{buildroot}%{_libdir}/gimp/2.0/*/*.*a
%find_lang gimp20 %{?no_lang_C}
%find_lang gimp20-libgimp %{?no_lang_C} gimp20.lang
%find_lang gimp20-python %{?no_lang_C} gimp20.lang
%find_lang gimp20-script-fu %{?no_lang_C} gimp20.lang
%find_lang gimp20-std-plug-ins %{?no_lang_C} gimp20.lang
echo "%%defattr(-,root,root)" >plugins.list
echo "%%defattr(-,root,root)" >plugins-python.list
for PLUGIN in %{buildroot}%{_libdir}/gimp/2.0/plug-ins/* ; do
    if grep -qr '^#!.*python' $PLUGIN ; then
	echo "${PLUGIN#%{buildroot}}" >>plugins-python.list
    else
	echo "${PLUGIN#%{buildroot}}" >>plugins.list
    fi
done
find %{buildroot} -type f -name "*.la" -delete -print
# Install the macros file:
install -d %{buildroot}%{_rpmmacrodir}
sed -e "s/@GIMP_APIVER@/%{apiver}/;s/@GIMP_ABIVER@/%{abiver}/" \
    < $RPM_SOURCE_DIR/macros.gimp > macros.gimp
install -m 644 -c macros.gimp \
           %{buildroot}%{_rpmmacrodir}/macros.gimp
%fdupes %{buildroot}%{_datadir}/gtk-doc/
%fdupes %{buildroot}%{_libdir}/gimp/2.0/python/
%fdupes %{buildroot}%{_datadir}/gimp/2.0/

%post -n libgimp-2_0-0 -p /sbin/ldconfig
%postun -n libgimp-2_0-0 -p /sbin/ldconfig
%post -n libgimpui-2_0-0 -p /sbin/ldconfig
%postun -n libgimpui-2_0-0 -p /sbin/ldconfig

%files -f plugins.list
%license COPYING LICENSE
%doc AUTHORS ChangeLog NEWS* README
%{_bindir}/gimp
%{_bindir}/gimp-2.*
%{_bindir}/gimp-console
%{_bindir}/gimp-console-2.*
# should this maybe be in _libexecdir too?
%{_bindir}/gimp-test-clipboard-2.0
%{_libexecdir}/gimp-debug-tool-2.0
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/gimp-data-extras.metainfo.xml
%{_datadir}/metainfo/org.gimp.GIMP.appdata.xml
%{_datadir}/applications/gimp.desktop
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/gimp/
%{_datadir}/gimp/2.0/images/gimp-splash.png
%{_libdir}/gimp/2.0/environ/default.env
%{_libdir}/gimp/2.0/interpreters/default.interp
# Explicitly list modules so we don't lose one by accident
%{_libdir}/gimp/2.0/modules/libcolor-selector-cmyk.so
%{_libdir}/gimp/2.0/modules/libcolor-selector-water.so
%{_libdir}/gimp/2.0/modules/libcolor-selector-wheel.so
%{_libdir}/gimp/2.0/modules/libcontroller-linux-input.so
%{_libdir}/gimp/2.0/modules/libcontroller-midi.so
%{_libdir}/gimp/2.0/modules/libdisplay-filter-color-blind.so
%{_libdir}/gimp/2.0/modules/libdisplay-filter-gamma.so
%{_libdir}/gimp/2.0/modules/libdisplay-filter-high-contrast.so
%{_libdir}/gimp/2.0/modules/libdisplay-filter-clip-warning.so
%{_mandir}/man?/gimp.*
%{_mandir}/man?/gimp-2.*
%{_mandir}/man?/gimp-console.*
%{_mandir}/man?/gimp-console-2.*
%{_mandir}/man?/gimprc.*
%{_mandir}/man?/gimprc-2.*
%{_mandir}/man?/gimptool-2.*
%dir %{_sysconfdir}/gimp
%dir %{_sysconfdir}/gimp/2.0
%config %{_sysconfdir}/gimp/2.0/*rc
# split file-aa into own package (bnc#851509
%exclude %{_libdir}/gimp/2.0/plug-ins/file-aa

%files plugin-aa
%{_libdir}/gimp/2.0/plug-ins/file-aa

%files -n libgimp-2_0-0
%dir %{_datadir}/gimp
%dir %{_datadir}/gimp/2.0
%dir %{_libdir}/gimp
%dir %{_libdir}/gimp/2.0
%dir %{_libdir}/gimp/2.0/environ
%dir %{_libdir}/gimp/2.0/interpreters
%dir %{_libdir}/gimp/2.0/modules
%dir %{_libdir}/gimp/2.0/plug-ins
%{_libdir}/libgimp-2.0.so.*
%{_libdir}/libgimpbase-2.0.so.*
%{_libdir}/libgimpcolor-2.0.so.*
%{_libdir}/libgimpconfig-2.0.so.*
%{_libdir}/libgimpmath-2.0.so.*
%{_libdir}/libgimpmodule-2.0.so.*

%files -n libgimpui-2_0-0
%{_libdir}/libgimpthumb-2.0.so.*
%{_libdir}/libgimpui-2.0.so.*
%{_libdir}/libgimpwidgets-2.0.so.*

%if %{with python_plugin}
%files plugins-python -f plugins-python.list
%{_libdir}/gimp/2.0/environ/pygimp.env
%{_libdir}/gimp/2.0/interpreters/pygimp.interp
%{_libdir}/gimp/2.0/python/
# FIXME: Maybe split gimp-lang and gimp-plugins-python-lang
%endif

%files lang -f gimp20.lang

%files devel
%doc README.i18n
%{_bindir}/gimptool-2.0
#{_mandir}/man?/gimptool-2.0%%{?ext_man}
%{_includedir}/gimp-2.0/
%{_libdir}/*.so
%{_datadir}/aclocal/gimp-2.0.m4
%{_libdir}/pkgconfig/gimp-2.0.pc
%{_libdir}/pkgconfig/gimpthumb-2.0.pc
%{_libdir}/pkgconfig/gimpui-2.0.pc
# Own these repositories to not depend on gtk-doc while building:
%dir %{_datadir}/gtk-doc
%{_datadir}/gtk-doc/html/
%{_rpmmacrodir}/macros.gimp

%changelog
* Tue May 21 2024 Paolo Stivanin <info@paolostivanin.com>
- Add fix-gcc14-build.patch (fix bsc#1223892)
* Mon May  6 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.10.38:
  * Fixed a crash with newer glib
  * Indexed PNGs with transparency are now exported with the correct colors
  * Anders Jonsson fixed the input ranges for several filters such as Waves and Distort
  * The titlebar customization field now supports UTF-8 characters
  * Existing image comments no longer “leak” into newly created images
* Wed Nov  8 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.10.36:
  - New features and improvements
  - ASE and ACB palettes support
  - New Gradient: FG to Transparent (Hardedge)
  - GIF: non-square ratio support
  - Text tool: improved formatting behavior when selecting and
    changing text on canvas.
  - Theme: better feedback when hovering lock buttons (with a white frame)
    as well as when activating a lock (a small padlock shows up in the corner).
  - Security and bug fixes
  - Fixed Vulnerabilities (DDS: ZDI-CAN-22093, PSD: ZDI-CAN-22094,
    PSP: ZDI-CAN-22096 and ZDI-CAN-22097)
  - Broken Graphics Tablets with recent linuxwacom driver
* Fri Jun 30 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: the biarch module is not used anymore.
* Tue Apr 18 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Do not recommend gimp-plugins-python even when we build it: it
  pulls in python2. Users are free to install it, but the default
  is not to do it anymore.
* Thu Apr  6 2023 Michael Gorse <mgorse@suse.com>
- Bump glib dependency to match the configure script.
* Thu Mar  2 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add boolean pkgconfig(babl-0.1) BuildRequires, allow build with
  new version of babl.
* Wed Feb 22 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.10.34:
  - Core:
  - Check for updates now works on macOS (backported from 2.99.14).
  - Update help IDs for better integration with the documentation website.
  - Symmetry dockable contents is now shown, yet deactivated, when no images are
    opened, improving discoverability (backported from 2.99.14).
  - DBus fully disabled on macOS (in some case, it could even freeze GIMP
    process when dbus is present yet not responding). Open With feature (e.g.
    from file browsers) still work fine as it uses a different code path on
    macOS. Other features using dbus (opening files or running batch commands
    from a separate GIMP process) won't work, but they probably never did on
    macOS anyway.
  - "Canvas Size" dialog took too much vertical space and now better uses the
    horizontal space by moving the preview and offset fiels to the right side,
    and the "Center" button just below (backported from 2.99.8).
  - Template selector (backported from 2.99.6) in resize dialog.
  - Color scale preferences (0..255/0..100 and LCh/HSV settings in Colors
    selection dialogs) are now remembered across sessions.
  - Eye icon header added to the item tree views to make it more obvious where
    to click for item visibility and links (backported from 2.99.10)
  - Revert color proofing behavior changed in 2.10.32 which resulted in
    inconsistent past workflows.
  - "Lock path strokes" tooltip for the dockable icon was renamed "Lock path".
  - Plug-ins:
  - DDS: make GUI translatable.
  - file-raw: added high bit depth precision export (partial backport from
    2.99.12).
  - TIFF:
  * Various bug fixes;
  * better check for invalid resolutions on import;
  * do not generated warnings for incorrect RichTIFFIPTC tags produced by
    Adobe products (only output a message to stderr, for not completely
    ignoring these);
  * Loading "reduced" image or not is now an option. We use a heuristic for
    the default value of said option (trying to guess if it's a thumbnail by
    using common usage), but final decision is now up to one knowing the image
    you load (backported from 2.99.14);
  * Default TIFF export format is "normal" TIFF, not BigTIFF (making it
    default was definitely an error in 2.10.32).
  - PSD:
  * Various bug fixes;
  * Useless physical unit conversion removed;
  * Backported improvement (2.99.10) for importing layers with clipping set
    (leading to color bleeding);
  * Backported improvements (2.99.10) for importing clipping layers;
  * Paths are now exported (backported from 2.99.14).
  - WebP: more informative error messages in some cases.
  - Flame: various bug fixes.
  - JPEG-XL:
  * metadata import backported from 2.99.14 - (requires libjxl 0.7.0)
  * Partial backport (2.99.8) of JPEG-XL export; export is always in 8bit
    lossless.
  - HEIF: various bug fixes.
  - Dicom: various bug fixes.
  - help:
  * macOS: https support now working fine for help files (bypassing
    lack of support in GIO for macOS platform).
  - animation-play: fixed on macOS.
  - PDF:
  * Import: new option "Fill transparent areas with white" to fill the
    background in white (ON by default as most office PDF writers seem to rely
    on readers filling the background with white), allowing importing
    transparent PDF files.
  * Export: new option "Fill transparent areas with background color" allowing
    to decide whether to export a PDF with transparent background.
  - TGA:
  * Added a workaround to load wrongful TGA files exported by Krita (which
    they fixed on their side too now, see Krita bug 464484).
  - ICO and CUR:
  * Magics detection for these formats has been removed (now using only using
    filename extension) because it was interfering with the detection of
    certain types of TGA images (which are likely more common than ICO and CUR
    files, and extension for these should be reliable enough).
  - Libgimpbase:
  - GimpMetadata API (in particular the gimp_metadata_set_from_*() functions)
    are now much less memory-hungry (backported from the main dev branch) when
    using GExiv 0.12.2 or over. With some huge metadata, it could cause long
    freeze or even crashes of plug-ins.
  - Libgimpwidgets:
  - Color-picking with X11 is now the default when compiled with X11, even if a
    color-picking portal also exists, because it is always right, whereas
    portals return color in display space without the space information itself
    (i.e. without profiles).
  - New dedicated GimpPickButton implementation for Windows (backported from
    2.99.14).
  - Libgimp:
  - New wrapper functions around GEGL ops, which also map to items in our Color
    menu:
  * gimp_drawable_shadows_highlights()
  * gimp_drawable_extract_component()
* Wed Jun 15 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.10.32: (boo#1199653 CVE-2022-30067)
  - Core:
  - Adding support for localized glyphs ('locl') in Text tool
    depending on the value of the "Language" field in Text tool
    options.
  - XCF import nows drop Xmp.photoshop.DocumentAncestors tags
    after 1000 of them, similarly to what libgimpbase now does.
    This could happen in XCF files which were created e.g. from a
    PSD import before we handled the issue in libgimpbase.
  - XCF import:
  - made more robust by ignoring (with a warning) invalid
    parasites and continuing to load the rest of the file
    (which might be valid). This way, we are able to salvage
    more cases of partially corrupted XCF files.
  - additional safety checks to detect broken XCF files.
  - Version check can be globally disabled through a value in the
    `gimp-release` file. This would allow to use the same build
    on repositories with an update channels (where we don't want
    update check notifications) and on standalone (where we want
    them).
  - User Interface:
  - Removed titlebar/borders from Windows Splash Screen.
  - All official themes now have on-hover indicator around eye
    and link toggles in Layer/Channel/Path Dialog tree-views.
  - Dark theme:
  - Hover-on effect on radio menu items to improve readability.
  - Color icon theme:
  - Thin contrast border for 'close' and 'detach' to improve
    their readability against dark backgrounds on mouse-hover.
  - Plug-ins:
  - TGA: improving indexed images with alpha channel support
    (both import and export).
  - DICOM: Fix endian conversion for photometric interpretation
    "MONOCHROME1".
  - file-raw: "RGB Save Type" confusing dialog label renamed to
    "Palette Type" as on the main dev branch.
  - screenshot: option to capture cursor in now available on
    Windows.
  - pygimp: new optional parameter `run_mode_param` (defaulting
    to True) to register() function of the Python binding, which
    allows to make the "run-mode" parameter optional when
    creating a new PDB procedure. This is already used to fix
    "file-openraster-load-thumb" without changing its signature.
  - BMP: new PDB procedure "file-bmp-save2" which supports all
    options available interactively.
  - BigTIFF: our TIFF plug-in now officially supports BigTIFF
    import and export.
  - Import was actually already working transparently if you
    had a recent enough libtiff. Now the recent libtiff is
    enforced by dependency requirements.
  - Export support was added with a checkbox in the interactive
    dialog and a new "bigtiff" argument in the "file-tiff-save"
    PDB procedure.
  - When an interactive export of ClassicTIFF fails for the
    explicit reason of "Maximum TIFF file size exceeded", the
    export dialog is raised again with a message proposing to
    try again as BigTIFF or trying another compression
    algorithm. This allows because discoverability and
    understandibility of the issue, while not forcing BigTIFF
    export (since it might not be supported everywhere).
  - Unlike the same change on the main dev branch, this
    backport comes without a dependency requirement bump, which
    means this will only work if GIMP is built with recent
    enough libtiff.
  - Raw: more robust load able to load as much as possible from
    the file, then fill the rest with white, when offset and
    dimensions are bigger than actual file size.
  - Improved support of a few plug-in code for building under
    UCRT Windows environment (more modern C runtime library than
    MINGW).
  - EPS: loading transparent EPS files now supported.
  - JPEG XL: import backported from the `master` (2.99) branch.
  - WebP: export has a new IPTC checkbox (saved through XMP) as
    well as a thumbnail checkbox. (backported from dev branch,
    since 2.99.8)
  - DDS: export has a new flip option (useful for some game
    engine) as well as a new savetype option to export all
    visible layers (not only the active one).
  - TIFF:
  - import support for 8 and 16 bit CMYK(A) TIFF files.
  - 1, 2 and 4-bit B/W images are now converted to indexed
    rather than grayscale as it seems that there is more of a
    use case for these images to be handled as indexed, even
    though technically they can be considered grayscale. In the
    future we could add an option at loading time where the
    user can choose whether they prefer it to be loaded as
    indexed or grayscale.
  - Fix loading images generated by MATLAB's blockproc
    function.
  - More robust loading for 8 bps grayscale MINISWHITE TIFF.
  - Libgimp:
  - New gimp_plug_in_error_quark() as a generic GQuark/GError
    domain for plug-ins (backported from 2.99.6).
  - gimp_drawable_brightness_contrast() now works in the [-1.0,
    1.0] range (it's more of a fix than a change because it's
    what it should have been from the start).
  - Better management of modification time in metadata: IPTC tag
    Iptc.Application2.DateCreated is not overridden anymore as it
    is the original creation date of the image. Instead we set
    the XMP tag Xmp.xmp.ModifyDate for file modification time and
    Xmp.xmp.MetadataDate for metadata modification time.
  - Format of Xmp.tiff.DateTime is now properly set with timezone
    as a consequence of the previous improvement.
  - Libgimpbase:
  - Limit to 1000 ancestors when importing images with incredible
    amount of `Xmp.photoshop.DocumentAncestors` tags, which is
    most likely due to a bug in some versions of Photoshop (in
    some PSDs, we encountered over 100,000 such tags; it probably
    makes no sense that a document could have that many ancestor
    documents). GIMP will now stops at 1000 such tags before
    dropping the rest and continue loading the file.
  - Icons:
  - Chain icons for the Color icon theme reworked from the
    Symbolic versions (with contrast borders to work on any
    background color) so that the "broken" and full variants are
    easily distinguishable.
  - Translations:
  - New Galician and Georgian translations for the Windows
    installer.
  - 20 translations were updated: Catalan, Chinese (China),
    Croatian, Danish, Dutch, Finnish, French, Georgian, German,
    Hungarian, Icelandic, Italian, Polish, Portuguese, Russian,
    Slovenian, Spanish, Swedish, Turkish, Ukrainian.
  - Build:
  - Bumping minimum GEGL to version 0.4.36.
- drop gimp-CVE_2022-30067.patch: included in update
* Tue May 24 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not recommend lang package: the lang package has smarter
  supplements in place.
* Wed May 18 2022 Michael Gorse <mgorse@suse.com>
- Add gimp-CVE_2022-30067.patch: fix out of memory when reading
  XCF (boo#1199653 CVE-2022-30067).
* Wed May  4 2022 Marcus Meissner <meissner@suse.com>
- switched to https urls
* Tue Dec 21 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.10.30
  - Core:
  - Do not follow subpixel font rendering choice from system
    settings for text layer rendering. These systems are useful
    for GUI rendering on a screen of a specific type and pixel
    order. Yet when rendering an image which can be zoomed in or
    out, showed on various screens or even printed, subpixel font
    rendering doesn't make sense.
  - Rewrite the core selection drawing logics so that it works on
    macOS Big Sur and over. This is a backport (adapted to GTK+2)
    of the fix brought in GIMP 2.99.8 for Wayland and macOS.
  - Ignore MakerNote metadata tag at export and only store the
    tags that go in it, hence avoiding partial invalid metadata.
  - Color picking from Colors dockable can now use the
    Freedesktop portal.
  - On Windows, move from GetICMProfile() to
    WcsGetDefaultColorProfile() because the former is broken in
    Windows 11.
  - Plug-ins:
  - metadata-viewer: improve how XMP tags with multiple values
    are handled and shown (now each value on a separate line for
    better readability).
  - metadata-editor:
  * XMP array tags of type BAG and SEQ are now on separate
    lines.
  * Comparing XMP tags with equivalent IPTC tags with multiple
    values, each value is compared individually, instead of
    comparing the list as a whole.
  - Many robustness improvements and other fixes to the metadata
    plug-ins.
  - AVIF: prefer AOM encoder for export.
  - PSD:
  * Skip sanity check for mask of rendered layers as some layer
    mask have invalid dimensions in such cases. They will now
    be loaded correctly.
  * Fixed loading of CMYK PSD files without alpha.
  * Fixed loading of CMYK images without layers.
  * Fixed loading of merged image of a 16 bit per channel RGBA
    PSD file with the alpha channel opaque.
  - PBM: large file export now always works and does not depend
    anymore on the platform's long int size.
  - Screenshot:
  * GNOME shell implementation dropped because the D-Bus API
    has been restricted to core components for security
    reasons, thus our plug-in was failing.
  * KDE portal moved as last fallback after the X
    implementation (when running on X) and Freedesktop portal,
    because KDE is also starting to block API calls for
    security reasons.
- drop 0001-Issue-6210-Subpixel-font-rendering-system-settings-s.patch
  included in update
* Fri Oct 22 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Add upstream patch (GIMP issue #6210)
  + 0001-Issue-6210-Subpixel-font-rendering-system-settings-s.patch
    Fix issue where the textool produces false color artifacts
    when using font anti-aliasing and system is set to subpixel
    rendering.
* Thu Oct  7 2021 Marcus Rueckert <mrueckert@suse.de>
- gimp-tips no longer has translations
* Sat Sep 18 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.10.28
  - Core:
  - Dashboard now has memory support in OpenBSD.
  - Default shortcuts Shift+[ and ] for tool size changed to {
    and }.
  - Performance improvements for GIMP on macOS Big Sur: these
    improvements were actually already applied in our macOS
    packages since GIMP 2.10.22, but were applied upstream
    directly only now.
  - User Interface:
  - Dark theme: improve accessibility of GtkRadioButton by adding
    a white border on mouse-hover.
  - Gray theme: set light background for selected text in Layers
    and Paths dockable dialogs to make text visible.
  - Dark, Gray and Light themes: remove 3D shadow box around eye
    and link toggles in Layers, Channels, and Paths dockable
    dialog tree views.
  - Plug-ins:
  - Improved DDS support and fix some red/blue bit swap for
    RGB10A2 DDS.  The plug-in version is incremented so that it
    is able to catch and correct previously incorrect RGB10A2
    images exported by older versions of our plug-in.
  - DDS files with "L16" - a 16 bit luminance channel - are now
    loaded in 16-bit.
  - DICOM images:
  * Support for planar configuration.  Support for deprecated
  * big endian transfer.
  - TIFF images:
  * Thumbnail storing now done by storing the thumbnail as the
  * second
    page in the file (through Exiv2) and setting metadata
    "Exif.Thumbnail.NewSubfileType" to 1 (reduced resolution
    image) instead of storing the thumbnail as a subifd. This
    was done because of a Windows bug locking TIFF files with
    thumbnail stored as subfid.
  * Symmetrically, loading will ignore pages marked as "reduced
    resolution image" (i.e. it will consider them as
    thumbnails), as well as try to guess if a page (without
    subfile type) is a thumbnail when it meets following
    criteria: second page with YCbCr PhotometricInterpretation,
    old style jpeg compression while the first page has a
    different PhotometricInterpretation or compression.
  - Script-fu:
  - New (dir-make "/dir/name" mode) function to create a
    directory.
  - Build:
  - Fix uninstalled white-border prelight file.
  - On Windows, *.rs file extension is not associated with SUN
    Raster images anymore. The reason is that this file extension
    is mostly used for Rust code files nowadays. If Windows could
    detect file formats with "magic numbers" (i.e. byte
    identifiers), it would not be a problem, but since it relies
    apparently only the extension, it's better to remove this
    association.
  - Oppositely on Linux and other Unix-like systems using desktop
    files, add the image/x-sun-raster MimeType which was
    forgotten (there, detection should be fine and not depend on
    file extension).
  - gimp30-tips.mo is not installed anymore (only used during the
    build to generate gimp-tips.xml with multiple language
    support).
  - --enable-check-update now has an "auto" value, which is the
    new default. It is equivalent to "yes" for Windows and macOS
    and "no" in all other cases.
  - New unit test to check that localizations listed in the
    installer script match available po files in
    po-windows-installer/.
  - "msys*" host value now detected as Windows builds.
  - Bumping minimum GEGL to version 0.4.32.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Fri Jun  4 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Move rpm macros.gimp from /etc/rpm to %%{_rpmmacrodir}.
* Mon Mar 29 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.10.24
  - Core:
  - Ignore Pentax and PentaxDng metadata at export because they are
    unsupported.
  - DBus calls (remote file open, typically with double click on file
    browser; and remote command run) are now processed after all command
    line files (in case of calls during startup) and in the call order
    (FIFO) for consistency. Some timeout has also been added to not spam
    the core process with non-processable DBus calls during startup.
  - Display profile name in "Color space" field of Image Properties and
    improve ellipsis & wrap on dialog fields whose contents' size is not
    controllable together with better dialog size management.
  - Fix stack overflow when loading very large XCF files on Windows.
  - Point snapping now works outside the canvas. This is used for snap
    to guides, grid and vectors. Snap to grid only works off-canvas when
    "Show All" is enabled because off-canvas grid is not visible
    otherwise, though snap to guide and vectors will always work
    off-canvas.
  - Libgimp:
  - Various metadata improvements:
  * Improve reading of iptc tags that appear more than once.
  - Plug-ins:
  - JPEG export will better advertize when metadata export fails,
    possibly with relevant error message. Image export would not fail,
    but at least we make the person aware metadata is not properly
    exported.
  - More robust TIFF import and export:
  * Better handling of Exif.Thumbnail.* tags on export.
  * Import now ignores TIFF pages with invalid directory (rather than
    freezing and output an error to warn of possible data loss).
  * Import attempts to count the directories by reading them when the
    headers does not announce any directory, which allows to salvage
    images with improper header. Also if reading of a directory fail,
    we now output a message to warn of possible data loss.
  * Fixed loading 2 and 4-bit TIFF images in grayscale and indexed.
  * Improve support of ExtraSamples fields with non-conformant TIFF
    files.
  * Improve loading of multi page tiffs with linear TRC.
  * More safety checks as a result of fuzz-testing.
  * Improve loading of MinIsWhite and MinIsBlack images.
  - GeoTIFF tag support added (recognized and stored into image
    parasites at import, then exported back when TIFF format is used)
    with appropriate "Save GeoTIFF data" checkbox (checked by default)
    to disable GeoTIFF metadata export when not desired.
  - The metadata viewer and editor got a big cleaning and refactoring
    pass, as well as various fixes and several improvements:
  * Fix handling of IPTC tags which can appear more than once (such as
    "Keywords") in both the viewer and editor.
  * Always read both the IPTC and XMP equivalent tags in the editor,
    instead of assuming they are necessarily the same.
  * More IPTC equivalents of XMP tags added:
    + Iptc.Application2.LocationName <=> Xmp.iptc.Location
    + Iptc.Application2.BylineTitle <=> Xmp.photoshop.AuthorsPosition
    + Iptc.Application2.CountryCode <=> Xmp.iptc.CountryCode
    + Iptc.Application2.Writer <=> Xmp.photoshop.CaptionWriter
  * The editor now properly saves IPTC tags.
  * Improve UTF-8 conversion to avoid double string conversion (hence
    actually breaking encoding).
  * Use proper unit abbreviations and proper label casing.
  * GPS data is now properly formatted with better precision and with
    translatable string parts and tooltips are added to explain how to
    correctly edit GPS data (latitude, longitude, altitude).
    Also seconds part of latitude/longitude is now saved with more
    precision and altitude details now switch from .1m to .10m.
  * Better error reporting when the editor fails to write a tag, with
    proper GUI error, so that such error do not go unseen.
  * Better error handling when closing the editor or viewer too, and
    improve error handling when the calendar dialog fails.
  * Use a logging domain for debugging-only messages which pollutes
    the output.
  * Xmp.iptc.CreatorContactInfo/Iptc4xmpCore:* override the shorter
    forms Xmp.iptc.Ci* if both are present, since the longer form is
    more common.
  * Improve saving of XMP metadata.
  * And more bug fixes and refactoring steps to get rid of duplicate
    code.
  - PNG will now prompt only for layer offset different from zero. Some
    software were always setting an offset of 0 (e.g.: POV-Ray v3.7) so
    GIMP would unecessarily prompt the user until now for PNG created by
    such software.
  - BMP:
  * allow loading of BMP images with incorrect BI_BITFIELDS
    compression.
  * support loading more bit depth such as 24bpp images.
  - file-darktable:
  * support updated Lua API of darktable 3.6 and beyond;
  * Adding environment contents to debugging output when
    DARKTABLE_DEBUG env variable is set.
  - PDF import:
  * New option to reverse order of layer.
  * Support fractional DPI (allowing accurate page dimensions).
  - DDS:
  * Set blue channel of BC5 dds images to 0 instead of 255.
  * Fix DDS BC5 compression/decompression with Red and Blue swapped.
    We detect images created by an older GIMP on loading and swap the
    channels back.
  - HEIF:
  * Removes the "HDR" mention on HEIF 10/12-bit export because high
    bit depth does not necessarily means HDR.
  * Runtime detection of HEIC and AVIF file formats (depending on
    available encoders and decoders), which allows afterwards update
    of the dependency, but also allows usage for a single format (e.g.
    for distributions which want to support only AVIF).
  * With libheif 1.10, visually lossless export is possible for
    10/12 bit depths too
  - PSD:
  * More flexible reading of layer mask record size, skipping invalid
    or unsupported mask info size, hence allowing us to load more PSD
    files (at least the part of a PSD we support instead of failing
    the whole import altogether).
  - G3 fax images:
  * Improve error handling when loading.
  * Be more forgiving on bad lines which were quite frequent on older
    fax images, allowing to salvage some old images.
- Drop 0001-app-make-gegl-introspect-an-optional-operation-depen.patch
- Drop libheif-avif-only.patch
* Fri Feb 12 2021 Michael Gorse <mgorse@suse.com>
- Recurse directories when looking for python plugins
  (boo#1180362).
* Mon Jan 25 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Make graphviz/dot only required for runtime debugging an
  optional dependency, fixes bsc#1180614:
  * 0001-app-make-gegl-introspect-an-optional-operation-depen.patch
- Cleanup spec file, remove Leap 42.x parts
* Thu Jan  7 2021 Alynx Zhou <alynx.zhou@suse.com>
- Added python-xml as recommend dependency. (bsc#1180363)
* Tue Oct 27 2020 Marcus Rueckert <mrueckert@suse.de>
- updates to buildrequires
  - synced required versions with configure.ac
  - convert more buildrequires to pkgconfig() versions
- enable libheif on Tumbleweed, since we have the version in TW
  with avif support, but not actual HEIF support unless libheif
  from packman is used.
- added libheif-avif-only.patch:
  libheif based exporter will only offer the formats supported by
  the installed libheif (via runtime check)
* Sun Oct 18 2020 Atri Bhattacharya <badshah400@gmail.com>
- Change macro defined to test whether to build python plugin from
  _with_python2 to _with_python_plugin since the complementary
  variable _without_python2 is already defined as `true` for
  openSUSE:Factory project wide (to disable building python2
  modules when using single-spec); this re-enables the python
  plugin for openSUSE Tumbleweed.
* Tue Oct  6 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.10.22:
  - Core:
  - Verbose version information (`gimp-2.10 -v` on command line,
    or debug output) now displays Flatpak related information
    when available. This is especially useful for debugging (such
    as the exact Flatpak build hash, the runtime version, the
    installed Flatpak extensions, permissions, etc.).
  - OpenCL settings has now been moved to the Playground tab in
    Preferences.
  - On stable builds, "Playground" tab is now visible in
    Preferences if any of the experimental features has been
    enabled, even without the CLI option `--show-playground`.
  - Tools:
  - "gegl:matting-levin" now the default engine of Foreground
    Select tool (when present, as it is an optional feature) as
    it performs a lot better.
  - GEGL operations now display a "Sample merged" checkbox in
    Tool Options. This will be used when the operation allows to
    pick a color (hence one can pick from the edited layer or
    from visible data).
  - "Sample merged" now defaults to being activated in Color
    Picker and GEGL tools as it seems the less confusing for
    beginners who don't know of the option yet (according to a
    small poll we ran).
  - User interface:
  - In GimpSpinButton, don't propagate Enter key-press events if
    updating the spin-button's value in response changes the
    entered text. This prevents confirming dialogs when hitting
    Enter after entering a math expression in size entries,
    updating their value instead.  Likewise, don't propagate
    Escape key-press events if a new value was entered, and
    restore the original value instead.
  - GimpMemSizeEntry improved to show appropriate binary prefixes
    (kibibyte, mebibyte and gibibyte) instead of decimal ones, to
    round properly when using higher units, and to not lose
    accuracy when possible when displaying in higher units.
  - Several of the biggest pages of the Preferences dialog are
    now scrollable, allowing the dialog to fit on smaller
    displays.
  - Plug-ins:
  - Add a new GIMP_EXPORT_NEEDS_CROP export capability, which
    causes gimp_export_image() to crop the exported image content
    to the image bounds; this is useful for formats that support
    layers, but have no concept of global image bounds, hence
    cropping is the only way to enforce the image bounds.  When
    showing the export dialog, give an option to either crop the
    layers to the image bounds, or to resize the image to fit the
    layers.
  - Content type `image/webp` is now recognized (and not only
    `image/x-webp` as both seem to be in used and this format is
    unfortunately not yet listed in IANA media types (so various
    content types are in use, no clear standard apparently).
  - DDS import is now a bit more permissive, allowing to load
    some files with invalid header flags regarding compression,
    while we are able to know the right compression from other
    flags. This allows to recover invalid DDS files exported by
    other software.
  - JPEG detection improved to be more generic and reliable.
  - HEIF support improvements:
  - AVIF importing and exporting added (requires libheif
    1.8.0+)
  - 10/12-bit importing and exporting now available for
    HEIC/AVIF
  - NCLX color profile import (link with LittleCMS)
  - Metadata support when importing
  - "Lossless" option is now called "Nearly lossless (YUV420
    format)" because this is actually what it is, hence
    previous naming was misleading.
  - TIFF support improvements:
  - Add an option to crop the layers to the image bounds when
    exporting individual layers (using GIMP_EXPORT_NEEDS_CROP),
    since TIFF has no concept of global image bounds otherwise.
    Cropping is enabled by default.
  - TIFF export will not override "DocumentName" metadata tag
    anymore.
  - Stop writing file paths into TIFF DocumentNames as file
    paths can contain confidential information such as
    usernames and directory structures, making the previous
    behaviour a potential privacy and security risk.
  - Fix a file descriptor leak case which may have prevented a
    file from being opened on Windows.
  - Multiple improvements in the PSP import plug-in:
  - support reading raster layers of PSP version > 6,
  - support reading 16-bit integer PSP files,
  - support reading grayscale and indexed PSP files,
  - support PSP images with zero-length layer names,
  - fix wrong layer offset of layers,
  - fix reading layer names with high bit ASCII characters,
  - fix incorrect loading of PSP images with uncompressed
    channel data,
  - fix reading of creator block data of PSP images,
  - better error messages describing yet unsupported features,
  - improve reader stability by always using the block/chunk
    length.
  - Spyrogimp now works on Grayscale images and clutters less the
    undo history.
  - "Orientation" metadata is now reset whether you accepted to
    rotate the image or not when importing an image.
  - XPM does not export a "None" (transparent) color when unused.
  - BMP always include color masks when exporting BMP with color
    space info, as mandated by BITMAPV5HEADER specification.
  - Debugging:
  - Add progressive performance logs: progressive logs contain
    complete information after each recorded sample, by writing
    partial address maps at each sample, containing all new
    addresses introduced by the sample.  This allows recording
    complete logs even in cases where they can't be properly
    terminated, such as when GIMP crashes or freezes in the
    middle of the log.  Progressive logs are disabled by default,
    since they potentially increase the sampling cost. They can
    be enabled through a toggle in the log file-dialog, or
    through GIMP_PERFORMANCE_LOG_PROGRESSIVE environment
    variable.  Performance log viewer can now process progressive
    performance logs too.
  - Allow controlling performance-log parameters through the UI.
  - Bug fixes: #2275, #2668, #2874, #3481, #3868, #4061, #4155,
    [#4328], #4505, #4536, #4560, #4816, #5043, #5069, #5208, #5219,
    [#5226], #5232, #5274, #5275, #5357, #5358, #5472, #5530, #5584,
    [#5592], #5623, #5630, #5651
* Tue Sep 15 2020 Michael Gorse <mgorse@suse.com>
- Make python 2 conditional, and disable on SLE/Leap (bsc#1082699).
* Wed Jul 22 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Solve the libexecdir problem a different way.
* Tue Jul  7 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec(bsc#1174075)
* Thu Jun 11 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 2.10.20:
  * Tool-group menus can now expand on hover
  * Non-destructive cropping now available by cropping the canvas
    rather than actual pixels
  * Better PSD support: exporting of 16-bit files now available,
    reading/writing channels in the right order
  * On-canvas controls for the Vignette filter
  * New filters: Bloom, Focus Blur, Lens Blur, Variable Blur
  * Blending options now built into filter dialogs
  * Over 30 bugfixes
* Mon Feb 24 2020 Marcus Rueckert <mrueckert@suse.de>
- disable update check
* Mon Feb 24 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.10.18:
  https://www.gimp.org/news/2020/02/24/gimp-2-10-18-released/
  - Core:
  - In gimp:replace, when compositing the same content over itself,
    i.e., when the input and aux buffers share the same storage and
    same tile alignment, pass the input buffer directly as output,
    instead of doing actual processing. In particular, this happens
    when processing a pass-through group outside of its actual bounds.
  - In gimp_gegl_apply_cached_operation(), use gint64 for storing the
    total and processed pixel counts used for reporting progress, to
    avoid overflowing when applying an operation to a large image.
  - In GimpFilterTool and gimp_drawable_apply_operation(), use
    gimp_drawable_filter_set_add_alpha() to add an alpha channel when
    applying an operation that specifies "needs-alpha" to a drawable
    that can have alpha.
  - In GimpFilterTool, move all the drawable-filter option setup to a
    new gimp_filter_tool_update_filter() function, and call it
    whenever the drawable-filter's options need to be updated. This
    avoids duplicating logic in various places.
  - Improve the efficiency of decoding RLE data when loading ABR
    brushes, by reading entire scanlines into a buffer all-at-once,
    instead of reading the stream byte-by-byte.
  - GIMP now optionally phones home to find out if there's a new
    version available and then tells the user if there is one indeed.
    It also keeps track of the installer revision and then warns if
    there's a newer installer available. This can be disabled in
    Preferences. In that case, users still have the option to manually
    check for an update via the About dialog. The feature can be
    disabled entirely with the '--disable-check-update' configure
    switch.
  - Tools:
  - New 3D Transform tool where you can set vanishing point, camera's
    focal length, and the move and rotate layer, selection, path, or
    image in 2.5 space. With the "Unified interaction" option enabled,
    all three interaction modes of the grid (camera, move, and rotate)
    are available simultaneously. In this mode, the inner and outer
    regions of the item are used for moving and rotation,
    respectively, and the vanishing point is controlled through
    through a handle.
  - Transform tools now respect the Clip option and update the canvas
    preview accordingly.
  - New "Composited preview" option allows respecting layer's blending
    mode and position in the layer stack rather than rendering it as
    an overlay on top of the overall layer stack. This simplifies
    creating complex layer compositions greatly. The option requires
    mipmaps to be used and thus is disabled by default. It also comes
    with an experimental "Synchronous preview" suboption to render the
    composited preview synchronously. This reduces the lag for
    painting the preview, but can harm responsiveness for bigger
    images, where rendering the preview is slow.
  - Add a new "Preview linked items" option to the transform-grid
    tools. When this option is enabled, together with composited
    previews, the transform preview includes all linked layers and
    channels when transforming a layer/channel. Paths are currently
    unsupported.
  - New widget called GimpPivotSelector, a 3x3 grid of toggle buttons,
    is now used for selecting a natural pivot position (e.g. for a
    transform) relative to an item: its center, its corners, and the
    midpoints of its edges. Currently used in Rotate and 3D Transform
    tools.
  - Add "Show all" support to the Bucket Fill tool in line-art mode
  - Color picker and sample points now support displaying vlaues in
    Yu'v' (CIE 1976 UCS) color space.
  - The Symmetry Painting dock now has an "Enable reflection" option
    that allows painting patterns resembling a kaleidoscope.
  - Transform clipping is temporarily disabled for layer groups. No
    preview other than 'Adjust' works anyway. This will be fixed later
    on.
  - Construct a box-filtered mipmap hierarchy for the original brush
    on-demand, and the closest mipmap is used as the resampling source
    for downscaled brushes, significantly improving the output
    quality.
  - Now that painting is done in a separate thread, the display update
    rate has a far smaller impact on it. Increase the GimpDisplay
    update rate, which handles image updates, to 60 FPS, and the
    GimpDrawTool update rate to 120 FPS. In particular, the latter
    change makes the brush outline motion much smoother.
  - In the Airbrush tool, increase the maximal stamp FPS from 15 to
    60, and change the corresponding maximal Rate value from 150 to
    100. This technically affects tool presets, but we'll live.
  - Add a new "Snap brush outline to stroke" toggle to the "Image
    Windows" preferences page. When enabled, the brush outline in
    paint tools snaps to the individual dabs while painting, which is
    how it worked before version 2.10.16. Disable the option by
    default.  This seems to be what most other programs are doing, and
    it does give paitning a smoother feel.
  - The Warp Transform tool now respects settings for painting tools:
    showing the brush outline, snapping to dabs, and showing the paint
    tool cursor.
  - User interface:
  - Add new Symbolic-High-Contrast and Symbolic-Inverted-High-Contrast
    themes, which are automatically-generated high-contrast variants
    of the (original) Symbolic theme.  The contrast factor is settable
    in the makefile, and is currently at 1.5 for both themes.
  - Rename tools/invert-svg to tools/svg-contrast, which now takes a
    contrast-factor argument, and adjusts the input SVG contrast,
    instead of just inverting it.  Note that we can still use the tool
    to invert icons, using a contrast of -1.
  - Allow horizontal scrollbars in all the Preferences dialog tree-
    views, so that they don't limit the minimal width of the dialog
    (in particular, the UI- and icon-theme tree-views may contain
    arbitrarily-long paths).
  - Draw a border around the color FG/BG color areas as a pair of
    black and white rectangles instead of letting GTK do this. This
    imporoves the legibility of borders, especially in dark themes.
  - Tools are now logically grouped in the toolbox by default. Users
    can customize the groups to their liking or disable this feature
    altogether in the Preferences dialog (Interface / Toolbox page).
  - New opt-out compact style for sliders with revamped interaction.
    The widget uses a narrower layout, and the different
    upper/lower-half behavior is gone. Instead, the behavior depends
    on the mouse button and modifier used:
  - left-click is used for absolute adjustment,
  - Shift + left-click + drag changes value in small increments,
  - Ctrl + left-click + drag changes value in large increments,
  - middle-click enables numeric input mode;
  - right-click enables numeric input mode and selects the value.
  - The "You can drop dockable dialogs here" message is gone from the
    toolbox for good. Instead, highlight dockable areas when a user
    starts dragging a dockable dialog, and intensify the highlight as
    the dialog goes over a dockable area.
  - Consolidate UI for merging down and anchoring layers: As they are
    both mutually exclusive and serve an almost identical purpose, the
    "Merge down" and "Anchor Layer" are given mutually exclusive
    visibility in menus, and the anchor button is replaced with a
    merge down button in the Layers dockable whenever there is no
    active floating selection. Modifier keys are available:
  - Shift: merge layer group
  - Ctrl: merge visible layers
  - Ctrl + Shift: merge visible layers from last used values
  - Tools:
  - In GimpPaintTool, when not snapping brush outline to stroke, make
    sure to properly snap the cursor position to 15-degree angle
    multiples in line mode, not only when painting the line, but also
    during motion.
  - Plug-ins:
  - Add naive support for CMYK 8-bit PSD files
  - In plug_in_compat.pdb, when wrapping an op node inside a graph,
    set the op node as the graph node's underlying operation. This
    allows gimp_gegl_apply_operation() to perform certain
    optimizations.
  - The Spyrogimp plugin now features a Visual tab where the inner
    mechanics of a spirograph is abstracted away, and you operate on
    amount of petals etc. The plugin now also allows saving a pattern
    as a path rather than rendering it to a layer as a bitmap.
  - Improve the loading speed for PSD files, mostly by eliminating
    excessive copies.
  - Filters:
  - Don't disable gegl:color-to-alpha (which has "needs-alpha") when
    the drawable doesn't have an alpha channel, if one can be added.
  - Don't disable color-to-alpha for grayscale drawable, since the
    operation is applicable to grayscale images (in particular, it
    doesn't add color where there was none), and since GIMP no longer
    distinguishes between layers and channels according to the
    drawable format when updating the filters actions.
  - Updated translations
  - Bug fixes #4643, #4634 #4172, #4194, #4205, #4218, #2543, #4185,
    [#4246], #2794, #4209, #4278, #4372, #4187, #4392, #2674, #4338,
    [#2862], #4203, #4204, #4354, #1266, #4584, #4174, #4285, #4366,
    [#1975], #4605
* Wed Nov 20 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix build for %%arm and ppc64 by adding '-lm' to LDFLAGS
* Thu Oct 31 2019 Marcus Rueckert <mrueckert@suse.de>
- bump babl and gegl deps to match configure script
* Thu Oct 31 2019 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.10.14:
  https://www.gimp.org/news/2019/10/31/gimp-2-10-14-released/
  + Core:
  - New "Selected areas continue outside the image" toggle option
    to the "Feather Selection" dialog.
  - New "Allow editing on non-visible layers" setting in
    Preferences to allow painting, transforming, and selecting on
    layers with toggled off visibility.
  - XCF loading a bit more resilient to corruption: it doesn't
    stop any more at the first layer or channel error; instead it
    tries to load more layers/channels to salvage as much data as
    possible from a corrupted XCF file.
  - In gimp:gradient, fix dithering to correspond to how we
    actually round float values to 8-bit. In particular, this
    avoids introducing noise when a component is fixed at 0 or 1
    along a segment.
  - New "Show All" view mode allowing to show pixels outside the
    canvas boundary.
  - New "Show Canvas Boundary" option to render a dotted line
    around the canvas boundary.
  - New "Keep Padding in "Show All" Mode" option, also available
    as a default option via Preferences, to preserve the padding
    color instead of displaying the checkerboard.
  - Several features updated to react as expected when run
    out-of-canvas: color-picking, canvas grid, transform tools,
    bucket fill, and more.
  - Loaded images' pixel density will now default to 72 PPI when
    no explicit resolution information was stored in the imported
    file.  Newly created images' default pixel density will
    continue to be based on the default image template (with
    value 300 PPI if it has not be changed), yet not loaded
    images anymore. 72 PPI is the common default in most software
    (and in standards such as Exif) so it makes sense we stick to
    it, only for loaded images.
  + Tools:
  - Free Select tool: fast copy|cut-paste modifiers (Alt +
    Ctrl|Shift) are now working even when the selection is not
    committed. Starting a fast copy|cut-paste will automatically
    close the polygon and commit the selection, accelerating fast
    usage of free selections.
  - Foreground Select tool: new "Grayscale" Preview Mode. Also, a
    color selector for "Color" preview (original preview mode)
    now available, to select any color and opacity for the
    preview.
  - Add a new "Image" transform type to the transform tools, in
    addition to the existing "Layer", "Selection", and "Path"
    transform types.  The "Image" mode transforms the entire
    image, rather than a single item. In tools with a preview,
    the preview shows the transformed image projection.  The
    clipping mode controls how the canvas is clipped during the
    transform; in particular, the ADJUST clipping mode resizes
    the canvas to fit its transformed size.
  - In GimpFilterTool, add a new "clipping" option, which can be
    either Adjust or Clip.  This option is controllable for
    layers, when there's no selection mask.  When set to Adjust,
    which is used by default, the filter's output may extent past
    the drawable's boundary, and the drawable will be resized to
    match the output when committed.
  - Gradient tool: offest support in shaped gradients
  + Plug-ins:
  - Simple 8-bit port of filters to GEGL: nl-filter, film,
    fractal-explorer, flame, blinds, jigsaw, gradient-flare,
    checkerboard, tile-small, curve-bend, sample-colorize,
    map-object, lighting, grid, despeckle, sphere-designer,
    contrast-retinex, hot, sparkle, cml-explorer, destripe,
    twain, animation-optimize, depth-merge, warp, imagemap,
    gimpressionist
  - Port of filters to GEGL with float support: van-gogh-lic.
  - Add color profile support for HEIF (only when libheif 1.4.0
    is available).
  - TIFF import will now ask (in interactive mode) how to process
    unspecified TIFF channels: non-premultiplied (used to be the
    default) alpha, premultiplied alpha, or just import as
    generic channel.
  - HEIF export now improved with same profile logics as JPEG or
    WebP (it can actually export higher bit-depth data, so
    profile logics should be the one as in PNG, but we only
    support 8 bpc HEIF for the time being).
  - HEIF export dialog now has a "Save color profile" checkbox
    allowing to not export with a profile when needed (needs
    libheif 1.4.0 or higher).
  - PDF exporting: text layers in layer groups are now exported
    as proper text.
  - Cleaned up the file-dds GUI, removed the "Advanced" expander.
  - gimptool external tool now install plug-ins into subfolders
    (this is not mandatory in GIMP 2.10 yet, unlike future GIMP
    3, but is already the recommended folder structure for
    plug-ins).
  - 3 procedures ("color-decode-ycocg",
    "color-decode-ycocg-scaled" and "color-decode-alpha-exp")
    removed from file-dds plug-in because they are hacks which
    should stay internal to the plug-in and are semantically wrong
    because colors in drawables are never in such formats.
  + Filters:
  - New "Normal Map" filter to generate normal maps from height
    maps in the Generic section.
  - Replace old filters with GEGL operation counterparts:
    edge-neon (gegl:edge-neon), contrast-normalize
    (gegl:stretch-contrast), oilify (gegl:oilify)
  - Add gegl:bayer-matrix and gegl:linear-sinusoid to Filters ->
    Render -> Pattern.
  - Add gegl:newsprint to Filters -> Distorts.
  - Add gegl:mean-curvature-blur to Filters -> Blur.
  + Performance:
  - Add an active-thread variable to the dashboard's misc group,
    showing the number of active worker threads.
  - Reduce time complexity of layer-group translation. When
    translating a layer group, avoid separately updating the
    original area of the child layers before translating them (as
    per the fix to issue #3484), as this results in quadratic
    time complexity w.r.t. to the maximal subgroup nesting level.
    Instead, simply defer the updating of the group's offset
    until *after* translating the child layers, so that their
    original area isn't clipped by the parent, while their new
    area is still properly updated even if the parent's size
    changes.
  + User interface:
  - Many mnemonics added in various dialogs.
  - Add a gimp-rotate-image-arbitrary action, and a corresponding
    "Image -> Transform -> Arbitrary Rotation..." menu entry,
    which activates the rotate tool in image mode (similarly to
    the corresponding action for layers).
  - On Windows, minimized GIMP window is now deiconified when
    GIMP is run again (clicking its shortcut or otherwise).
  + Preferences:
  - New "Swap compression" option: explicit control over the
    tile-swap compression algorithm in GEGL. "Best performance"
    is used by default, "Balanced", "Best compression", and
    "None" (disables compression) are available.
  + Devel docs:
  - Update the libgimpconfig and libgimpbase docs.
  - Update docs with missing symbols and types.
  - New docs for structs and enums.
  + Debugging:
  - New mnemonic-clashes tool to help looking for mnemonic
    clashes.
  + Updated translations.
* Sat Jun 15 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.10.12:
  + Core:
  - Add an "Incremental" option to the Dodge/Burn tool, which,
    similarly to the Paintbrush, Pencil, and Eraser tools,
    applies the effect incrementally as the pointer moves.
  - Curves now have a concept of smooth vs corner points: smooth
    points produce a smooth curve, while corner points produce a
    sharp curve (previously, all points were smooth).
  - Search the user font directory path on Windows (since Windows
    10, non-admin users have the ability to install fonts). This
    is only a temporary hack until fontconfig adds proper
    upstream support.
  - In gimp_brush_core_get_paint_buffer(), when allocating a new
    paint buffer, clear the old buffer *before* allocating the
    new one, to reduce the amount of simultaneously allocated
    memory.
  - In GimpPaintbrush, avoid refilling the paint buffer at each
    dab if the paint color/pixmap hasn't changed, hence allowing
    faster painting in some specific cases.
  - Add hygon cpu detection and enable MMX/SSE support.
  - Add a GimpSymmetry::get_transform() virtual function and a
    corresponding gimp_symmetry_get_transform() function which
    return the brush transform corresponding to a given symmetry
    stroke in terms of the rotation angle and reflection flag (in
    contrast to gimp_symmetry_get_operation() which returns the
    same transforation in terms of a GeglNode). This allows us to
    simplify, fix (artifact bugs, etc.), and improve the
    painting-code performance for several symmetry painting
    cases.
  - New gimp-brush-pipe-spacing parasite set by core code to
    preserve GIH brush's spacing across reloads.
  - Add a new Offset filter tool, as a front-end to gimp:offset.
    The tool replaces, and provides the same interface as the
    drawable-offset dialog while also providing live preview and
    on-canvas interaction.
  + Plug-ins:
  - Exported profile and data format strategy updated in several
    file plug-ins.
  - When not saving a profile, we always export as sRGB data, as
    most viewers would not display the image properly otherwise.
  - When saving a profile:
    . If a profile was manually assigned, we always export to the
    assigned format, hence pixel data is converted accordingly,
    whatever the work format.
  - If no profile was assigned:
    . If the export format support high-bit depth, we export the
    work format as-is.
    . If the export format is 8-bit max, we convert the work
    format to sRGB, except if the work format is 8-bit linear.
  + The following plug-ins were updated: JPEG, PNG, TIFF and WebP.
  + Tools:
  - Add input/output spin-buttons to the Curves tool, which allow
    setting the selected point's coordinates numerically. When
    the image precision is greater than 8-bpc, use a 0.00-100.00
    range for the point-coordinate spin-buttons instead of a
    0-255 range.
  - In the Curves tool, allow changing the curve's point types
    (cf. new curve corner points in Core section). Corner points
    are displayed with a diamond shape instead of a circle.
  - Free Select tool now creates a selection as soon as the
    polygon is closed. This selection is updated when the
    polygon, or the relevant tool-options, change, similarly to
    GimpRectangleSelectTool.
  - Derive GimpEraser from GimpPaintbrush, instead of directly
    from GimpBrushCore. This allows GimpEraser to reuse the
    paint-buffer content across dabs, improving performance.
  - Allow moving an intersecting pair of guides with the Move tool.
  + User interface:
  - In GimpCurveView, when dragging an existing curve point,
    don't immediately move the point to the cursor position upon
    button press, but rather move it relative to its current
    position as the cursor moves. This allows selecting a point
    without moving it, and adjusting its position more easily.
  - When the cursor hovers above a point in GimpCurveView, or
    when dragging a point, have the coordinate indicator show the
    point's position, rather than the cursor's.
  - In GimpCurveView, when holding down Ctrl while
    adding/dragging a point, snap the y-coordinate to the
    original curve (at the start of the drag). This is
    particularly useful for adding points along the curve.
  - In GimpDashboard, don't show legend for groups with no meter.
  - Add a tile-alloc-total variable to the dashboard's memory and
    misc groups, showing the total amount of memory used by the
    tile allocator.
  - Add a "Save Keyboard Shortcuts Now" button to the Configure
    Keyboard Shortcuts dialog.
  + Updated translations.
* Sun May  5 2019 ecsos@opensuse.org
- No more need pkgconfig(glib-2.0) >= 2.56.0 for build.
  pkgconfig(glib-2.0) >= 2.54.2 is enough.
* Sun Apr  7 2019 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.10.10:
  - Core:
  - Add gimp-scratch allocator, a fast memory allocator (on the
    order of magnitude of alloca()), suitable for small (up to a
    few megabytes), short-lived (usually, bound to the current
    stack-frame) allocations.  Unlike alloca(), gimp-scratch
    doesn't use the stack, and is therefore safer, and will also
    serve bigger requests, by falling-back to malloc().
  - In gimp_drawable_transform_buffer_affine(), avoid modifying
    the clipping mode when transforming layer masks, since this
    function is used (among other things) to transform layer
    masks together with their layer, in which case they should
    use the same clipping mode as the layer. This fixes a
    regression introduced by commit 2ae823ba, causing layer masks
    to be transformed with a mismatched clipping mode during
    layer transforms, leading to discrepencies between the
    transformed layer and the transformed mask.
  - Moved swap/cache and temporary files out the GIMP user config
    dir and added new config file substitutions ${gimp_cache_dir}
    and ${gimp_temp_dir}.
  - Pass the GEGL tile-cache size, swap path, and thread-count to
    plug-ins as part of their config, and have libgimp set the
    plug-in's GeglConfig accordingly upon initialization.
  - Layer groups are now rendered in bigger chunks rather than
    tile-by-tile (which used to pretty much eliminate
    multithreading for groups), which improves the rendering
    speed.
  - Make saving/exporting files more robust to errors. In
    particular if an error occurs during the process (be it a
    bug, a memory error, or anything else), GIMP won't overwrite
    anymore any existing file with incomplete contents, so that
    you won't end up with no valid files at all.
  - Fix a regression on support of various graphics tablet.
  - Remove the "Edit -> Fade..." feature: it makes GIMP use two
    buffers instead of one (east into system resources), it's
    broken in 2.10, and we can make the UX better for filters.
  - New generic canvas modifier 'Alt + middle click' allowing to
    pick layers by clicking on pixels. The available layers will
    be looped through (starting from the upper one) while Alt key
    is hold and the picked layer name will be temporarily
    displayed in the status bar.
  - When clearing a channel, do nothing if the channel is already
    empty; otherwise, align the cleared rectangle to the channel
    buffer's tile grid, so that all affected tiles are dropped,
    rather than zeroed.  Furthermore, only update the affected
    region of the channel.
  - Brush and pattern saving logics has been moved to core code
    (instead of plug-in).
  - Clipboard brushes and pattern can now be duplicated.
  - Parametric brushes are now 32-bit float to avoid
    posterization on large brushes.  Note: raster brushes are
    still 8-bit and plug-ins only have access to 8-bit versions
    of high-precision brushes/patterns. New API will be required
    to handle high-precision data.
  - On-canvas preview while editing a color in the colormap of an
    indexed image.
  - User interface:
  - Enabled HiDPI/Retina support for the GTK2/OSX build, fixes
    blurry icons.
  - Add a tooltip to the "better compression" checkbox in save
    dialog to make it clearer it does not mean that the file size
    is necessarily smaller in every cases. In particular some
    best/worst case are possible when an algorithm less efficient
    in general may end up better on a particular image.
  - Add basic support for cursors with a scale factor of 2 for
    HiDPI (artwork to be updated).
  - Foreground and background color icons, as well as color
    history will now display out-of-gamut warning on indexed
    images for colors outside of the palette, as well as on
    grayscale images, for non-gray colors.
  - Pack color picker and hexadecimal entry on same line in Color
    dock.
  - Add an "Open as Image" button to the brushes dialog.
  - Usability:
  - Attempting to transform locked layers or paint on them now
    results in blinking around the status bar (where the warning
    message is displayed) and around the toolbar where lock
    toggles are. The same applies to attempting to move a
    selection where there is none — GIMP will blink around the
    toolbar where the moving target (layer, selection, path) is
    chosen.
  - GIMP now allows selecting default export file type for new
    projects.  The choice is limited to PNG, JPEG, WebP, PSD,
    ORA, TIFF, BMP.
  - GimpSpinScale widget now has an optional feature to constrain
    the value to integer when dragging with a pointer (even if
    the scale allows for fractional numbers), set with new
    function gimp_spin_scale_set_constrain_drag().  This is
    useful for settings where fractional numbers are technically
    possible, yet most common use case are with integers (such as
    pixel sizes, angles in degrees, etc.) so you want the easy
    interface to be constrained. Fractional numbers are still
    settable, for instance by keyboard edit; and arrow
    incrementation won't drop fraction parts.  This is currently
    only activated for brush options in paint tools.
  - Tools:
  - In scale tool, scale around center even when using numeric
    input.
  - New algorithm in the Bucket Fill tool when selecting the
    affected area "Fill by line art detection", based off the
    G'Mic algorithm for "smart colorization":
    https://hal.archives-ouvertes.fr/hal-01891876 In a few words,
    it identifies painted pixels (either based on grayscale or
    opacity values) and tries to close line arts to allow filling
    even with not perfectly closed zones; the second step of the
    algorithm will flood the colors under line art pixels to
    prevent "holes" in the filling.  It is possible to control a
    max size (in pixels) for the flooding, as well as max length
    of closing segments and splines.
  - The Bucket Fill tool got new interaction allowing to hold the
    click and move the mouse to fill based on several seed zones
    (for "Fill by line art detection" as well as "Fill similar
    colors"). You can now cancel the fill in progress with right
    click as in other tools.
  - The Bucket Fill tool now allows color picking with
    ctrl-click, same as every painting tool. It will pick either
    the foreground or background color depending on the selected
    Fill Type. The ctrl-alt modifier combination is also possible
    to pick the non-Fill Type color.
  - In the Bucket Fill tool, the Alt modifier will now switch to
    "FG color fill" when "Pattern fill" was set (instead of doing
    nothing).
  - In the Unified Transform tool, default to preserving aspect
    ratio when scaling up or down.
  - In the Healing tool, "Sample merged" now also work for the
    target pixels, allowing to draw in empty layers.
  - Selection by color is now parallelized, hence improving speed
    of the Select by Color tool (and any other processing which
    may share this piece of code now or in the future).
  - Add "Constrain handles" and "Around center" options to the
    perspective-transform tool's GUI, which are similar to the
    corresponding options of the unified-transform tool.
  - Improve color picking on indexed image to always select an
    indexed color corresponding to the picked pixel in the
    colormap.
  - Plug-ins:
  - file-pdf-save GUI now clearly indicates the order the layers
    will be used to make multi-page PDFs.
  - Add DDS loading/exporting plug-in originally developed by
    Shawn Kirst and Arne Reuter.
  - Rename the Guillotine plug-in to Slice Using Guides.
  - Add a new option saving a color profile when exporting PNG,
    JPEG, TIFF.  Always save it when exporting to PSD.
  - Remove the "Advanced" expanders from the PNG and TIFF export
    dialogs.
  - Full rewrite of the Spyrogimp plug-in with much more options
    and better interaction.
  - Indexed TIFF with alpha channel now supported.
  - Filters:
  - Add on-canvas GUI (simple lines) for circular, linear, and
    zoom motion blur.
  - Help:
  - Link to the bugtracker directly from the Help menu, also link
    to the wiki and the roadmap. Remove the link to currently
    disabled registry.gimp.org.
  - Translations:
  - Czech, Danish, French, Italian, Japanese, Marathi, Polish,
    Russian, Spanish, Swedish, Ukrainian.
* Mon Mar 25 2019 mvetter@suse.com
- bsc#1130407: Remove dependency on JasPer.
  OpenJPEG is actually used.
* Fri Nov  9 2018 sean@suspend.net
- Update to vesion 2.10.8:
  +Core:
  - Use adaptive chunk size in GimpProjectio nwhen rendering the
    projection asynchronously, rather than using a fixed chunk size.
    This provides a better trade-off between throughput and
    responsiveness dynamically, based on how fast the processing is.
  +Tools:
  - In all selection tools, show error on attempt to
    subtract-from/intersect-with empty selection.
  - Fix text along path not working with vertical text.
  - Fix Text tool's frame position when undoing a move operation.
  - Streamline Text tool's drawing blocking/unblocking logic.
  - When moving a text layer using the text tool (through alt-drag),
    don't change the layer's box mode to "fixed", which is unnecessary,
    since the layer's size isn't affected.
  - Transform and deformation operations now maintain color for fully
    transparent pixels, making unerase and curves manipulation of alpha
    channel more reliable.
  - All transform tools now apply changes when you asve or export/overwrite
    an image without pressing Enter first to confirm changes.
  - Heal, Dodge/Burn, Smudge and Convovle tools now adjust the processed
    buffer and mask_buffer regions according to the changes made to the
    application region, as calculated by intersecting it with the
    drawable and mask extents. This fixes wrong application position
    when painting on a drawable whose origin is above/to the left of the
    image's origin, and there's a selection active.
  +Plug-ins:
  - Port all plug-ins to the new iterator API in GEGL.
  - Improve automatic detection of HEIC/HEIF files.
  - Improve RawTherapee discovery by looking up registry key (should
    become useful with RawTherapee 5.5 and more).
  +Usability:
  - Compatibility information in the Save dialog is now more understandable.
    The minimum GIMP version for the XCD file is always written down when it
    is GIMP 2.8 or over. The list of features warranting the minimum version
    is now listed in an expander container rather than as tooltip, which
    makes it more discoverable. The warning on compression is now displayed
    as its own text under the checkbox and not as additional text to the minimum    GIMP version label.
  +CLI:
  - New self-explanatory --enable-win32-debug-console CLI option
  +Translations:
  - Updated translations: Danish, Dutch, Finnish, German, Hungarian,
    Italian, Polish, Portugese (Brazil), Spanish, Swedish, Ukranian.
* Mon Sep 17 2018 ecsos@opensuse.org
- pkgconfig(glib-2.0) >= 2.56.0 is needed.
* Thu Aug 23 2018 bjorn.lie@gmail.com
- Update to version 2.10.6:
  + Core:
  - Render drawable previews asynchronously.
  - Merge the file view filter and file format lists in
    GimpFileDialog. The presence of 2 lists was very confusing.
  - DLL search priority is now updated before running a plug-in
    on Windows, depending on the executable bitness. This gets
    rid of one of the last remnant of DLL hell in GIMP, which was
    when running 32-bit plug-ins from a 64-bit build of GIMP.
  + Filters:
  - New "Little Planet" (gegl:stereographic-projection) filter.
  - New "Long Shadow" (gegl:long-shadow) filter.
  + Tools:
  - Halt the Measure tool after straightening.
  - Add an "orientation" option to the measure tool,
    corresponding to the "orientation" property of
    GimpToolCompass (i.e., it controls the orientation against
    which the angle is measured, when not in 3-point mode.) The
    orientation is "auto" by default, so that the angle is always
    <= 45 deg.  Note that the "orientation" option affects the
    tool's "straighten" function, so that the layer is rotated
    toward the current orientation.
  - Text layers can now represent vertical texts, with 4
    variants: left-to-right and right-to-left lines, and forcing
    all characters to be upright or following Unicode's vertical
    orientation property. See also:
    https://www.unicode.org/reports/tr50/
    http://www.unicode.org/Public/UCD/latest/ucd/VerticalOrientation.txt
  + User Interface:
  - The Dashboard dockable dialog now has an "async" field to the
    dashboard's "misc" group, showing the number of async
    operations currently in the "running" state.
  - New Preferences option to enable/disable layer-group
    previews, since these can get quite time-expensive.
  + Updated translations.
* Fri Jul  6 2018 ecsos@opensuse.org
- fix build error for Leap 42.3
- add missing requires
* Fri Jul  6 2018 mrueckert@suse.de
- bump versions in BR according to the configure.ac
- move library requires in libgimp to %%requires_ge and also force
  the libgegl update
* Thu Jul  5 2018 mrueckert@suse.de
- update to 2.10.4 bug fix release
  Core:
  - Remove gimp_display_shell_draw_background() and all clipping
    hacks for drawing the canvas background. This optimizes away
    one entire step of drawing of image size, for each expose.
  - Font loading does not block startup anymore. Only consequence
    is that the Text tool may not be usable immediately if fonts
    are not fully loaded yet (and will output an appropriate error
    if you do so). All non-text related activities can be performed
    right away.
  - Change of the URL from bugzilla to gitlab where appropriate.
  - New tool option manager to better keep track of user context
    and paint options in a consistent manner.
  User Interface:
  - The Dashboard dockable dialog now has a 'Memory' group that
    shows memory-usage information: the currently used memory size,
    the available physical memory size, and the total physical
    memory size.  It can also show the tile-cache size, for
    comparison against the other memory stats. Note that the
    upper-bound of the meter is the physical memory size, so the
    memory usage may be over 100%% when GIMP uses the swap.
  - The Dashboard dockable dialog now has "read" and "written"
    fields in the dashboard swap group, which report the total
    amount of data read-from/written-to the tile swap, respetively.
    Additionally, the swap busy indicator (used as the meter's LED)
    has been improved, so that it's active whenever data has been
    read-from/written-to the swap during the last sampling
    interval, rather than at the point of sampling.
  - Fonts can now be tagged. The user interface is the same as for
    brushes, patterns etc.
  - Some icons fixed: larger spacing between broken chains and
    gimp-tool-ellipse-select made symmetrical.
  Usability:
  - When a plug-in cannot be applied to an image because of
    mismatch in image types (e.g. layer has no alpha or image is
    greyscale), GIMP now displays a message listing supported image
    types for this plug-in.
  Tools:
  - The Measurement tool now has an "Auto straighten" option
    allowing to rotate the active drawable (layer, channel…) so
    that the measurement line is used as horizon. As other
    transform tools, the feature will work on linked drawables as
    well.
  - The Smudge tool now paints correctly on images with a color
    profile other than the GIMP's built-in one.
  Build:
  - Installer: set compatibility options to run Python plugins in
    HiDPI-aware mode.
  - Put back compatibility DLLs for really old plugins.
  - Install binary tool `gimp-test-clipboard` on the system to
    allow people to help us debug clipboard bugs.
  - --enable-bundled-mypaint-brushes renamed
  - -enable-relocatable-bundle and also make WMF fonts looked up
    on the runtime prefix of GIMP (instead of the build-time path)
    when this build option was set.
  Plug-ins:
  - gimptool-2.0 binary now accepts source files with non-standard
    extensions if it can try to guess appropriate language from the
    compiler being used. It will also properly quote arguments for
    shell usage.
  - Run explicitly Python 2 as Python plug-in interpreter to
    prevent breakage on systems where Python 3 is the default.
  - raw_input()'s argument in Python console is now optional, and
    input() support has been added.
  File Formats:
  - The PSD loader now provides an option to load "merged",
    pre-composited version of the images that becomes available
    when a PSD file was saved with "Maximize Compatibility" option
    enabled in Photoshop. This is useful when loading PSD files
    that use features that GIMP doesn't currently support, and
    therefore can't render correctly, such as adjustment layers.
    When loading the merged image version, we avoid loading certain
    additional data from the file, such as channels, paths, and
    guides, while still loading metadata. This option is currently
    exposed as an additional file type ("Photoshop image
    (merged)"), which has to be explicitly selected from the
    file-type list when opening the image.
  - Embedding GIMP's built-in sRGB color profile to exported files
    is now optional. The default choice can be set in the
    Preferences dialog.
  Translations:
  - Updated translations: Catalan, Czech, Danish, Dutch, Finnish,
    Greek, Hungarian, Italian, Latvian, Polish, Romanian, Russian,
    Spanish, Swedish, Ukrainian.
* Mon May 21 2018 plinnell@opensuse.org
- update to 2.10.2 bugfix release
- drop gimp-Fix-reference-to-gegl-0.3.patch
  + Core:
  - Discard fonts which fail to load and popup an info dialog to allow
    people debug their fonts.
  - New API to suppress updates in UI until plug-ins are done
    introducing changes.
  - New API to calculate histograms in separate threads, with possible further
    extension to handle similar cases elsewhere in GIMP.
  - Tool options are now properly saved and reloaded per-device at
    startup.
  + Plug-ins:
  - New plug-in for importing and exporting HEIF images.
  - Enable visibility of rasterized vector layer from PSD.
  - Single-window screenshots in Windows fixed to correctly snap a
    window even when it is partly off-screen or covered by another
    window or when display scaling is not set to 100%%.
  + Filters:
  - New Spherize filter to wrap an image around a spherical cap
  - New Recursive Transform filter to create Droste effect.
  + Usability:
  - Warn users, when alpha-only painting has no effect. E.g. when target
    drawable doesn't have an alpha channel, or the alpha channel is locked.
  - Make the splash texts dynamic, so they are larger on larger splashes.
  - Mention pressing Enter to complete Foreground selection in the status bar.
  - Make sure that clicking outside any selection prevents Rectangle Select
    and Ellipse Select tools from creating empty selections.
  - Improve mouse wheel zooming behavior to keep the same point
    centered under the pointer even if the image is completely visible
    in the canvas.
  - Add "View -> Center Image in Window" (Shift+J) as a quick way to
    center the image at any zoom level.
  + Translations:
  - Updated translations: Catalan, Danish, Dutch, French, German, Greek,
    Hungarian, Icelandic, Italian, Latvian, Polish, Russian, Spanish,
    Swedish, Ukrainian.
  - New translation of Windows installer: Chinese (Taiwan)
  + Build:
  - Add a --with-bug-report-url configure option allowing packagers to
    set the address of their own bug tracker. This address will be the
    one opened by the debug dialog for reporting bugs.
  - Add a flatpak manifest for the gtk3-port branch.
  - Remove the possibility to disable script-fu.
  - Add a --with-icc-directory configure option to customize the color
    profile directory. By default, it is set to the common path
    /usr/share/color/icc.
  + Documentation:
  - Updating the description of the XCF format "devel-docs/xcf.txt", for
    third-party readers wishing to support GIMP 2.10 XCF files.
  - Add documentation skeletons for all enums in libgimpbase/, there is
    much room for improvement.
* Wed May  2 2018 bjorn.lie@gmail.com
- Add gimp-Fix-reference-to-gegl-0.3.patch: gimp.pc: Fix reference
  to gegl-0.3 - we require and build for gegl-0.4 now.
* Mon Apr 30 2018 badshah400@gmail.com
- Update BuildRequires versions to be consistent with configure
  script.
* Mon Apr 30 2018 jweberhofer@weberhofer.at
- let libgimp-2_0-0 require libbabl-0_1-0 >= 0.1.46 to enforce updating
  to the required version.
* Sat Apr 28 2018 jweberhofer@weberhofer.at
- libbabl is required in version 0.1.46+
* Sat Apr 28 2018 mrueckert@suse.de
- add BR for gdk-pixbuf-loader-rsvg to enable svg icons
- enable jpeg2000 support: new BR pkgconfig(libopenjp2)
- enable webp support: new BR pkgconfig(libwebp) >= 0.6.0
- enable OpenEXR support: new BR pkgconfig(OpenEXR)
- enable email support: new BR/R for xdg-utils for xdg-email
- set LC_ALL/LANG in %%prep and %%build to silence warnings about
  encoding of the translations
- make sure we can see the compiler cmdlines by disabling the
  silent rules
* Fri Apr 27 2018 bjorn.lie@gmail.com
- Update to version 2.10.0:
  + Image processing nearly fully ported to GEGL, allowing high bit
    depth processing, multi-threaded and hardware accelerated pixel
    processing, and more.
  + Color management is a core feature now, most widgets and
    preview areas are color-managed.
  + Many improved tools, and several new and exciting tools, such
    as the Warp transform, the Unified transform and the Handle
    transform tools.
  + On-canvas preview for all filters ported to GEGL.
  + Improved digital painting with canvas rotation and flipping,
    symmetry painting, MyPaint brush support.
  + Support for several new image formats added (OpenEXR, RGBE,
    WebP, HGT), as well as improved support for many existing
    formats (in particular more robust PSD importing).
  + Metadata viewing and editing for Exif, XMP, IPTC, and DICOM.
  + Basic HiDPI support: automatic or user-selected icon size.
  + New themes for GIMP (Light, Gray, Dark, and System) and new
    symbolic icons meant to somewhat dim the environment and shift
    the focus towards content (former theme and color icons are
    still available in Preferences).
  + And more, better, more, and even more awesome!
- Drop gimp-gegl03-buildfix.patch: Fixed upstream, following this
  drop libtool BuildRequires and no longer pass autoreconf.
- Replace pkgconfig(gegl-0.3) with gegl-0.4) BuildRequires.
- Add gcc-c++, gegl, glib-networking, pkgconfig(gexiv2),
  pkgconfig(liblzma), pkgconfig(libmypaint),
  pkgconfig(mypaint-brushes-1.0) and pkgconfig(poppler-data)
  BuildRequires: New dependencies.
* Thu Mar  8 2018 bjorn.lie@gmail.com
- Add gimp-gegl03-buildfix.patch: Port to gegl-03, patch taken from
  debian.
- Following the above port, replace pkgconfig(gegl-0.2) with
  pkgconfig(gegl-0.3) BuildRequires and add libtool BuildRequires:
  and pass autoreconf as the above patch touches the buildsystem.
* Sun Jan  7 2018 zaitor@opensuse.org
- Run spec-cleaner, modernize spec, drop Obsoletes for versions
  no longer supported.
* Sat Jan  6 2018 plinnell@opensuse.org
- Don't build with webkit1, as it is no longer maintained and has
  plenty of security bugs.  This disables the GIMP's built-in help
  browser; it will use an external browser when configured this way.
  This works around a number of security vulnerabilities in Webkit1:
  https://bugzilla.suse.com/show_bug.cgi?id=923223
  https://bugzilla.suse.com/show_bug.cgi?id=906375
  https://bugzilla.suse.com/show_bug.cgi?id=906374
  https://bugzilla.suse.com/show_bug.cgi?id=906373
  https://bugzilla.suse.com/show_bug.cgi?id=1034856
  https://bugzilla.suse.com/show_bug.cgi?id=871792
  https://bugzilla.suse.com/show_bug.cgi?id=879607
  https://bugzilla.suse.com/show_bug.cgi?id=892084
* Wed May 31 2017 plinnell@opensuse.org
- drop mypaint until it is in Factory.
* Fri May 12 2017 plinnell@opensuse.org
- update to 2.8.22
- drop upstream patches - now in the the source
- drop gimp-fix-PDF-Import-filter-crash.patch
- drop gimp-bgo773233-CVE-2007-3126.patch
- conditionalize mypaint support
- full change log:
  https://git.gnome.org/browse/gimp/plain/NEWS?h=GIMP_2_8_22
* Sat Feb 25 2017 mailaender@opensuse.org
- Build with libmypaint support.
* Tue Feb 21 2017 zaitor@opensuse.org
- Add gimp-bgo773233-CVE-2007-3126.patch: Gimp 2.3.14 allows
  context-dependent attackers to cause a denial of service (crash)
  via an ICO file with an InfoHeader containing a Height of zero
  (bgo#773233, CVE-2007-3126).
- Add gimp-fix-PDF-Import-filter-crash.patch: Fix a crash in PDF
  Import filter when importing large image PDF or specifying high
  resolution (bgo#593576).
* Thu Feb  9 2017 zaitor@opensuse.org
- Add conditional gimp-help-browser Obsoletes for Tumbleweed and
  Leap newer than 42.x.
* Wed Feb  8 2017 jengelh@inai.de
- Remove --with-pic, this is only for static libs.
- Trim description on non-main subpackages.
* Fri Feb  3 2017 plinnell@opensuse.org
- update to 2.8.20
- Core:
  - Avoid D-Bus error message when built without D-Bus support
  - fix OS X min required conditional in gimpimagewindow.c
  - Saving to existing .xcf.bz and .xcf.gz files didn't truncate them
  and could lead to unnecessarily large files
  - Text layer created by gimp-text-fontname doesn't respect border
  when resized
  - avoid seeking when saving XCF files to prevent corruption with
  file network shares (fixed since 2014, but not mentioned in NEWS yet)
  GUI:
  - Flow on Paint Dynamics editor dialog: the 'y' axis is indicating
  'Rate' instead 'Flow'
  - Vertical ruler shows artifacts if the status bar isn't showing
  - Tablet stylus misbehaves when crossing the edge of a dock in
  multi-window-mode
  - Disable the new "automatic window tabbing" feature introduced on macOS
  Sierra
  - Improve the visiblity of slider handles with dark themes
  - Make it harder to switch to renaming if selecting already selected
  items in resource lists
  Tools:
  - make toggling to color picker mode of paint tools more robust
  Libgimp:
  - call gimp_file_entry_set_filename() with filename encoding
  Plug-ins:
  - Prevent the Python console from closing by the Escape key
  - Help browser does not launch on OS X
  - Filter 'Edge Detect/Difference of Gaussians' returns empty image
  - only use -xobjective-c for compile commands
  - mkgen.pl: fix calls to write_file() routine to write to current
  directory
  - When printing, the images are composed onto a white background to
  prevent printing a black box instead of a transaprent image
  - Fix color visison deficiency display filters to apply gamma
  correction directly
  Updated Translations:
  - Catalan  - Czech  - Danish  - Finnish  - French  - German
  - Greek  - Hungarian  - Icelandic  - Italian  - Polish
  - Portuguese  - Slovak  - Slovenian  - Scottish Gaelic
  - Spanish  - Swedish
  General:
  - Bug fixes
* Sun Jan 15 2017 zaitor@opensuse.org
- Replace -devel BuildRequires for their pkgconfig version aligned
  with what configure looks for:
  - babl-devel for pkgconfig(babl).
  - gegl-devel for pkgconfig(gegl-0.2).
  - libpng-devel for pkgconfig(libpng).
  - libpoppler-glib-devel for pkgconfig(poppler-glib).
  - xorg-x11-libXfixes-devel for pkgconfig(xfixes).
  - xorg-x11-libXpm-devel for pkgconfig(xpm).
  - zlib-devel for pkgconfig(zlib).
- Add an explicit pkgconfig(cairo-pdf) BuildRequires: configure
  checks for it (full pdf support).
- Run spec-cleaner: drop obsolete clean, modernise macros.
- No longer depend on libwebkit-devel for Tumbleweed and pass
  - -disable-webkit to configure for Tumbleweed.
* Sun Jul 31 2016 plinnell@opensuse.org
- update to 2.8.18
- Drop gimp-Multiple-Use-After-Free.patch - upstreamed
  +Core: - Initialize fontconfig cache in separate thread to keep GUI
  responsive on first startup
  - Properly recognize layer masks as deactivated, e.g. for moving layers
  - Create $XDG_DATA_HOME if it doesn't exist
  - (CVE-2016-4994) Multiple Use-After-Free when parsing XCF channel
  and layer properties
  - Fix progress access to prevent crash on rapid sequence of commands
  - Fix crash in gimp-gradient-segment-range-move
  +GUI:
  - Disable color picker buttons on OS X to prevent a GUI lockup
  - Disable "new-style" full-screen mode on OS X to prevent a crash
  - Pulsing progress bar in splash screen to indicate unknown durations
  - Fix gamut warning color for lcms display filter
  - Fix unbolding of bold font on edit
  - Prevent accidental renaming of wrong adjacent item
  +Installer:
  - Change compression settings to decrease size by 20%%
  - Add Catalan, Danish, French, Dutch
  +Plug-ins:
  - Fix crash on sRGB JPEG image drag & drop
  - Fix ambiguous octal-escaped output of c-source
  - Fix KISS CEL export
  - Fix progress bar for file-compressor
  - Make Script-Fu regex match return proper character indexes for
  Unicode characters
  - Fix Script-Fu modulo for large numbers
  +General:
  - Documentation updates
  - Bug fixes
  - Translation updates
* Thu Jun 23 2016 zaitor@opensuse.org
- Fix CVE-2016-4994 (boo#986021, bgo#767873):
  + Add gimp-Multiple-Use-After-Free.patch: Multiple Use-After-Free
    when parsing XCF channel and layer properties.
* Sat Dec  5 2015 plinnell@opensuse.org
- Explcitly declare the libgimp version in Requires, so upgrades
  bring in the updated libraries as well. Makes the upgrade from
  2.8.x > 2.8.16 seamless and avoids an error on start.
* Sat Nov 28 2015 plinnell@opensuse.org
- update to version 2.8.16
- fix a couple of rpmlint warnings
  +Core:
  - Seek much less when writing XCF
  - Don't seek past the end of the file when writing XCF
  - Windows: call SetDLLDirectory() for less DLL hell
  - Fix velocity parameter on .GIH brushes
  - Fix brokenness while transforming certain sets of linked layers
  +GUI:
  - Always show image tabs in single window mode
  - Fix switching of dock tabs by DND hovering
  - Don't make the scroll area for tags too small
  - Fixed a crash in the save dialog
  - Fix issue where ruler updates made things very slow on Windows
  +Plug-ins:
  - Fix several issues in the BMP plug-in
  - Make Gfig work with the new brush size behavior again
  - Fix font export in the PDF plug-in
  - Support layer groups in OpenRaster files
  - Fix loading of PSD files with layer groups
  + General:
  - OSX build system fixes
  - Bug fixes
  - Translation updates
* Wed Apr  8 2015 dimstar@opensuse.org
- Replace liblcms-devel BuildRequires with pkgconfig(lcms2): gimp
  has been ported to lcms2 since version 2.8.8.
* Sat Sep 20 2014 mailaender@opensuse.org
- update to version 2.8.14:
  + Fix libtool versioning (forgot to bump gimp_interface_age).
- Changes from Version 2.8.12:
  + Core:
  - Fix brush sizes when used from plug-ins.
  - Make XCF loading more robust against broken files.
  + GUI:
  - Make sure the widget direction matches the GUI language.
  - Remove the option to disable the warning when closing a
    modified image.
  - Fix canvas overlay widgets (like the text options) for
    tablets.
  - Make DND work between images in one dockable.
  + Libgimp: Make gimp_image_get_name() return the string used for
    the image title.
  + Plug-ins:
  - Make script-fu-server more secure by listening to 127.0.0.1
    by default and add a warning about changing that IP. This
    breaks the procedure's API, but for security reasons.
  - Bring back proper script-fu translations.
  + General:
  - Add Jenkins tutorial.
  - Documentation updates.
  - Bug fixes.
  + Updated translations.
- Drop gimp-use-recommended-freetype-include.patch: fixed upstream.
* Wed Dec 11 2013 hrvoje.senjan@gmail.com
- Add gimp-use-recommended-freetype-include.patch:
  Freetype upstream recommends using their macros together with
  ft2build include. Positive sideeffect is that this patch makes
  it build with both freetype2 2.5.1, and older versions.
* Sun Dec  1 2013 dimstar@opensuse.org
- Update to version 2.8.10:
  + Core:
  - Set manifest as Windows 8 compatible.
  + GUI:
  - Indicate if a file was exported in the Quit dialog.
  - Add shortcuts and hint labels to the close and quit dialogs
    that make closing and quitting easier and more consistent.
  - Rename the File->Export menu labels to match Save/Save as.
  - Fix keyboard shortcuts on OSX Mavericks.
  - Don't open lots of progress popups when opening many files.
  - Correctly restore the hidden state of docks in single window
    mode.
  + Libgimp:
  - Fix exporting an image consisting of a single layer group.
  - Don't attempt to pick transparent colors.
  + Plug-ins: Fix crash in LCMS plugin if RGB profile was missing.
  + General:
  - Fix compile on NetBSD (missing -lexecinfo).
  - Bug fixes.
  + Updated translations.
* Tue Nov 26 2013 dimstar@opensuse.org
- Update to version 2.8.8:
  + General:
  - Fix lots of places to use GIO to get proper file sizes and
    times on windows.
  - Add an AppData file for GIMP.
  - Backport lcms2 support from master, because lcms1 is not
    getting bug fixes any longer.
  - Lots of bug fixes.
  + Core:
  - Make sure indexed images always have a colormap.
  - Fix language selection via preferences on Windows.
  - Don't crash on setting a large text size.
  + GUI:
  - Keep the same image active when switching between MWM and
    SWM.
  - Make sure all dockables are properly resizable (particularly
    shrinkable).
  - Add links to jump directly to Save/Export from the
    Export/Save file extension warning dialogs.
  + Libgimp: Fix GimpPickButton on OSX.
  + Plug-ins:
  - Properly document plug-in-autocrop-layer's PDB interface.
  - Fix importing of indexed BMPs.
  + Updated translations.
- Split out ASCII-Art plugin in subpackage gimp-plugin-aa. The
  package supplements gimp and libaa1, so any user having both
  installed will get the plugin as well (bnc#851509).
* Sat Sep 21 2013 dimstar@opensuse.org
- Change RPM Group of shared library package to System/Libraries.
* Mon Aug 19 2013 dimstar@opensuse.org
- Drop branding-upstream subpackage: starting with openSUSE 13.1,
  we will no longer replace the gimp splashcreen with a branded
  version. This in order to maintain the identity of gimp.
- Remove gimp-branding Requires.
- Obsolete gimp-branding.
* Sat Jun 22 2013 zaitor@opensuse.org
- Update to version 2.8.6:
  + Core:
  - Fix saving to URIs, it was broken to only allow exporting,
    and fix save/export of compressed files.
  - Fix brush spacing for drawing in any direction.
  - Increase the maximum size of clipboard brushes and patterns
    to 1024x1024.
  - Make sure data objects are saved when only their name was
    changed.
  + GUI:
  - Don't allow single-window docks to shrink smaller than their
    requisition.
  - Make sure a single-window's right docks keep their size
    across sessions.
  - Allow to change the spacing of non-generated brushes again.
  - In single-window mode, make Escape move the focus to the
    canvas, and beep if the focus is already there.
  - Be smarter about unavailable fonts, and don't crash.
  - Make clicking the single-window's close button quit GIMP.
  - Make view-close (Ctrl+W) only close image windows and tabs,
    not docks.
  + Libgimp: Add SIGNED_ROUND() which also rounds negative values
    correctly.
  + Plug-ins:
  - Make GIMP_PLUGIN_DEBUG work again after GLib changed logging.
  - Fix zealous crop for transparent borders.
  + Installer: Add Hungarian translation.
  + Data: Add a default "Color from Gradient" dynamics and tool
    preset.
  + General: Lots of bug fixes.
  + Updated translations.
* Thu Mar  7 2013 dimstar@opensuse.org
- Update to version 2.8.4:
  + Core:
  - Move the OSX gimpdir to "~/Library/Application Support".
  + GUI:
  - Better names for the default filters in save and export
  - Make tool drawing (esp. the brush outline) much more
    responsive
  - Remember the "maximized" state across sessions
  - Simplify the splash image code a lot, makes it appear
    immediately again
  - Allow the text tool to start on an image without layers
  - Various fixes for text style attribute handling
  - Set unconfigured input devices to eraser if GTK+ says they
    are erasers
  - Make language selectable in Preferences on OSX
  + Libgimp:
  - Make libgimp drawable combo boxes aware of layer groups
  - Make sure plug-in windows appear on top on OSX
  - Fix item width in GimpPageSelector (used e.g. in PDF import)
  + Plug-ins:
  - Better default values in the Drop Shadow script
  - Fix a whole bunch of bugs in the BMP plug-in
  - On OSX, use the system's screenshot utility
  + Installer:
  - Add Brazilian-Portuguese translation to the Windows installer
  + Source and build system:
  - Many improvements to the OSX bundle build system
  - Support automake 1.13
  + General: Lots of bug fixes
  + Updated translations.
- Drop gimp-CVE-2012-5576.patch: fixed upstream.
* Tue Nov 27 2012 dimstar@opensuse.org
- Add gimp-CVE-2012-5576.patch: fix memory corruption vulnerability
  when reading XWD files (bnc#791372, bgo#687392, CVE-2012-5576).
* Wed Aug 29 2012 dimstar@opensuse.org
- Update to version 2.8.2:
  + Core:
  - Make tag matching always case-insensitive
  - Let the tile-cache-size default to half the physical memory
  + GUI:
  - Mention that the image was exported in the close warning
    dialog
  - Make sure popup windows appear on top on OSX
  - Allow file opening by dropping to the OSX dock
  - Fix the visibility logic of the export/overwrite menu items
  - Remove all "Use GEGL" menu items, they only add bugs and zero
    function
  - Improve performance of display filters, especially color
    management
  - Fix the image window title to comply with the save/export
    spec and use the same image name everywhere, not only in the
    title
  - Fix positioning of pasted/dropped stuff to be more reasonable
  + Libgimp:
  - Move gimpdir and thumbnails to proper locations on OSX
  - Implement relocation on OSX
  - Allow to use $(gimp_installation_dir) in config files
  + Plug-ins:
  - Fix remembering of JPEG load/save defaults
  - Revive the page setup dialog on Windows
  + Source and build system:
  - Add Windows installer infrastructure
  - Add infrastructure to build GIMP.app on OSX
  + General:
  - Lots of bug fixes
  + Updated translations.
- Drop gimp-CVE-2012-3236.patch: fixed upstream.
- Clean spec-file using spec-cleaner.
* Mon Jun 25 2012 vuntz@opensuse.org
- Add gimp-CVE-2012-3236.patch: fix crash in file handling for fit
  files. Fix CVE-2012-3236, bnc#768376.
* Mon May 14 2012 vuntz@opensuse.org
- Correctly version librsvg-devel BuildRequires: 2.36.0 is needed.
  We don't version the BuildRequires on 12.1 and earlier to avoid
  useless unresolvables; it will just result in file-svg plugin not
  being built when librsvg is not recent enough there.
* Thu May  3 2012 badshah400@gmail.com
- Update to version 2.8.0:
  + Core: Add gimp's own GimpOperationBrightnessContrast because
    GEGL one is different
  + Plug-ins: Fix some GFig rendering issues
  + Source and build system: Depend on Babl 0.1.10, GEGL 0.2.0
    and some other new library versions.
* Sat Apr  7 2012 vuntz@opensuse.org
- Update license from GPL-2.0+ to GPL-3.0+, following upstream
  change.
- Completely drop HAL-related packaging since it is now gone
  upstream:
  + Remove build_hal macro
  + Remove optional hal-devel BuildRequires.
  + Remove optional gimp-module-hal subpackage.
  + Note that we already have a Obsoletes for gimp-module-hal.
- Add pkgconfig(gudev-1.0) BuildRequires for the new gudev input
  module.
- Add ghostscript-devel, ghostscript-library, libbz2-devel,
  libjasper-devel, pkgconfig(atk), pkgconfig(xcursor)
  BuildRequires: new dependencies upstream.
  + Note about ghostscript-library: ideally, we'd avoid listing it
    explicitly, but in OBS, ghostscript-mini is preferred by
    default, but it is not enough for gimp.
- Add explicit pkgconfig(gdk-pixbuf-2.0) BuildRequires so it can be
  versioned.
- Add explicit libjpeg-devel, xorg-x11-libXpm-devel, zlib-devel
  BuildRequires: they were missing before.
- Add libxslt-tools BuildRequires (or libxslt-devel on versions of
  openSUSE <= 12.1) to have xsltproc installed.
- Add fdupes BuildRequires and use %%fdupes in %%install to avoid
  duplicated files.
- Change gimp-doc Obsoletes in devel subpackage from <= to < to
  avoid rpmlint warning about self-obsoletion.
* Fri Apr  6 2012 dimstar@opensuse.org
- Update to 2.8.0-RC1:
  + User Interface:
  - Single-Window Mode
  - Multi-Column Dock Windows
  - More Screen Real Estate For Dockable Dialogs
  - Save And Export
  - Layer Groups
  - Tools Drawn With Cairo
  - On-Canvas Text Editing
  - Keyboard Shortcut Changes
  - Simple Math In Size Entries
  + Tools & Plug-ins:
  - Brush System Improvements
  - Tool Preset Improvements
  - Cage Transform Tool
  - File Plug-Ins
  - For Tablet Users
  - Resource Tagging
  + Miscellaneous:
  - Enhancements to scripting abilities
  - API changes
  + For detailed changes, see NEWS file and
    http://www.gimp.org/release-notes/gimp-2.7.html
* Wed Feb  1 2012 vuntz@opensuse.org
- Update to version 2.6.12:
  + Bugs fixed: bgo#623045, bgo#627328, bgo#631728, bgo#631885,
    bgo#639203, bgo#640219, bgo#640612, bgo#641259, bgo#646947,
    bgo#652280, bgo#660305.
  + Updated translations.
- Drop gimp-CVE-2010-4540-and-more.patch: fixed upstream.
- Drop gimp-CVE-2010-4543.patch: fixed upstream.
- Drop gimp-fix-linking.patch: fixed upstream.
- Drop gimp-CVE-2011-2896.patch: fixed upstream.
- Drop gimp-pyslice-cellspacing-fix.patch: fixed upstream.
- Drop gimp-poppler-0.18.patch: fixed upstream.
- Remove call to autoreconf and libtool BuildRequires: they were
  only needed for gimp-fix-linking.patch.
* Fri Oct 21 2011 vuntz@opensuse.org
- Change gimp-2.0-scanner-plugin Recommends to a Suggests: this
  installs xsane by default, and really, xsane is so horribly
  broken UI-wise that we don't want that.
* Sat Oct 15 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Wed Oct 12 2011 vuntz@opensuse.org
- Add a warning comment about changing the content of the branding
  package, to make our life easier in branding-openSUSE.
* Thu Oct  6 2011 vuntz@opensuse.org
- Add iso-codes Recommends since the iso-codes data is used at
  runtime, but its presence is not mandatory.
- Remove explicit gtk2 Requires: the library will get
  automatically added to the list of Requires.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update gimp-fix-linking.patch: add another missing -lm.
- Add gimp-poppler-0.18.patch: fix build with poppler 0.17/0.18.
* Fri Sep  9 2011 vuntz@opensuse.org
- Add gimp-fix-linking.patch: fix linking issue.
- Add gimp-CVE-2011-2896.patch: Fix heap corruption and buffer
  overflow in LZW code. Fix bnc#711491, CVE-2011-2896.
- Add gimp-pyslice-cellspacing-fix.patch: fix a crash in the
  pyslice plugin.
- Add call to autoreconf, needed by gimp-fix-linking.patch.
* Wed Jul  6 2011 vuntz@opensuse.org
- Change branding-upstream subpackage:
  + Add Requires for gimp since the branding package is useless
    without it.
  + Update summary and description.
  + Make noarch.
- Change branding Requires in main subpackage to be "= %%{version}",
  instead of ">= 2.4", which is wrong.
* Wed Jun 15 2011 vuntz@opensuse.org
- Fix build on Factory, by not excluding the
  libcontroller-linux-input.so module from the file list of the
  main package when we build without hal. It was only excluded to
  be part of a hal subpackage when there is the hal dependency.
* Sat Jun 11 2011 vuntz@opensuse.org
- On 12.1 and later, stop building the gimp-module-hal subpackage:
  + we don't want hal anymore on 12.1 and later (see bnc#697016).
    We use a build_hal define to control that behavior.
  + remove hal-devel BuildRequires
  + do not build a gimp-module-hal subpackage anymore
  + add gimp-module-hal Obsoletes for smooth upgrades
* Tue Feb 15 2011 vuntz@opensuse.org
- Add gimp-CVE-2010-4540-and-more.patch and
  gimp-CVE-2010-4543.patch to fix buffer overflows: CVE-2010-4540,
  CVE-2010-4541, CVE-2010-4542, CVE-2010-4543. Fix bnc#662043.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Fri Jan  7 2011 vuntz@opensuse.org
- Move ownership from various directories from gimp to
  libgimp-2_0-0, to not force external gimp plug-ins/modules/etc.
  to have a gimp BuildRequires for directory ownership.
* Mon Dec 20 2010 vuntz@opensuse.org
- Split gimp libraries in libgimp-2_0-0 and libgimpui-2_0-0
  subpackages, and add baselibs.conf for those. Fix bnc#660439.
- Change accordingly the Requires of the devel package, and the
  scriptlets to run ldconfig.
- Remove explicit glib2-devel and gtk2-devel Requires in devel
  package: they will automatically be added the pkgconfig() way.
- Move the gimptool-2.0 man page to the devel subpackage, where the
  binary lives.
* Tue Nov 23 2010 aj@suse.de
- Change lang package Requires to Recommends since it is not
  mandatory at runtime.
* Mon Oct  4 2010 vuntz@opensuse.org
- Update to version 2.6.11:
  + bgo#631199: Printing and Print preview broken with cairo 1.10
  + Other bugs fixed: bgo#572865, bgo#628893, bgo#623850,
    bgo#624487, bgo#557380, bgo#627009, bgo#626020, bgo#624698,
    bgo#624275.
  + Updated translations.
* Mon Aug  9 2010 vuntz@opensuse.org
- Add alsa-devel BuildRequires to build the MIDI Input module.
* Tue Aug  3 2010 dimstar@opensuse.org
- Update to version 2.6.10:
  + bgo#613328: TGA files saved with incorrect header yOrigin data
  + bgo#623290: Save As... does not save Windows Bitmap as default
    in dialog
  + bgo#621363: CMYK decompose broken
  + bgo#595170: brush - color from gradient works wrong in
    greyscale
  + bgo#613838: Error in gimp-hue-saturation PDB call
  + bgo#622608: GIMP crashes when clicking any scroll bar from
    combo boxes
  + bgo#565459: newly opened images are put into the background
- Changes from version 2.6.9:
  + bgo#612618: Font selection remains visible
  + bgo#620604: Description of "histogram" procedure is slightly
    inaccurate
  + bgo#541586: Tool options not saved/loaded correctly?
  + bgo#614153: Importing PDF files with long titles
  + bgo#599233: Dialog of "Save as BMP" ignores changes which are
    not made with a mouse
  + bgo#610478: Layer preview suddenly stops getting updated
  + bgo#609026: leaks shared memory
  + bgo#609056: Exporting to Alias PIX format fails
    are always in English
  + bgo#607242: GIMP 2.7.0 fails to build against libpng 1.4.0
  + bgo#606372: Saving to .ppm fails on indexed colorspace
  + bgo#604508: gimp-layer-new-from-visible should work from
    updated projection
  + Fix crashes: bgo#600112, bgo#565001, bgo#604820, bgo#603711
  + Other fixes: bgo#622234, bgo#622196, bgo#608188, bgo#605237
  + Updated translations.
- Drop gimp-new-libpng.patch and gimp-fix-statusbar.patch, both
  came from upstream git and are now included.
* Mon Jun 14 2010 vuntz@opensuse.org
- Ship the openSUSE palette so that it's available in GIMP.
* Sun May 23 2010 vuntz@opensuse.org
- Add gimp-fix-statusbar.patch to fix missing widgets in status
  bar. Fix bnc#601712.
* Sun May 23 2010 vuntz@opensuse.org
- Move the input device module to a specific package, to isolate
  the HAL dependency. Fix bnc#601947.
* Tue Apr  6 2010 vuntz@opensuse.org
- Add gimp-new-libpng.patch to fix build with newer libpng.
* Fri Dec 11 2009 vuntz@opensuse.org
- Update to version 2.6.8:
  + bgo#470698 - MapObject cannot modify highlight
  + bgo#593848 - FG color changed to black when FG-BG Editor tab
    created
  + bgo#594651 - layer.scale() raises RuntimeError
  + bgo#594998 - Keyboard shortcuts does not work for first image
    when dock is focused
  + bgo#599765 - F1 key on gimp-tool-align in menu have wrong link
    and it open gimp-tool-move
  + bgo#600484 - Gimp BMP Integer Overflow Vulnerability
  + bgo#600741 - "read_channel_data()" Integer Overflow
    Vulnerability
  + bgo#601891 - gimp_image_get_selection returns None
  + bgo#602761 - plug-in-grid: Parameters Horizontal/Vertical
    Spacing and Horizontal/Vertical Offset are
    reversed.
  + bgo#603995 - PCX plugin doesn't sanitize input to avoid
    allocation overflows.
  + bgo#603998 - PCX: Calculating amount of memory to allocate may
    overflow.
  + bgo#604000 - SGI: sanitize input
  + bgo#604001 - SGI: Calculating amount of memory to allocate may
    overflow.
  + bgo#604002 - SGI: RLE encoded input data may write beyond
    allocated buffers
  + bgo#604004 - SGI: allocate memory consistently
  + bgo#604008 - GBR, PAT: sanitize input data
  + bgo#604078 - Crash when pressing Backspace with Free Select
    Tool
  + Updated translations.
* Mon Oct 26 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Fri Sep  4 2009 vuntz@novell.com
- Change Name in .desktop file to "GIMP", not "The GIMP". The
  project has stopped calling it the GIMP.
* Thu Aug 20 2009 crrodriguez@suse.de
- add support for versioning external plugins, providing
  rpm macros gimp_abi_version and gimp_api_version
* Wed Aug 19 2009 beineri@opensuse.org
- Everyone calls it "GIMP" so let us follow that in the application
  start menu, fixes problem with launcher finding it (bnc#508279).
* Fri Aug 14 2009 beineri@opensuse.org
- Update to version 2.6.7:
  + bgo#591017 - Tablet pan is not working as fast as it should
  + bgo#577581 - Crashes when using any colors tool/function on
    Windows
  + bgo#589667 - GIMP crashes when clicking GEGL Operation on
    Windows
  + bgo#569833 - file-jpeg-save erroneous with small quality
    values
  + bgo#590638 - Changing palettes from list to grid view loses
    "locked to dock" status
  + bgo#589674 - "Send by Email" does not update "Filename"
  + bgo#589674 - "Send by Email" does not update "Filename"
  + bgo#586851 - Transparent BMP files fail to load
  + bgo#589205 - help-browser uses deprecated (and sometimes
    broken) webkit call
  + bgo#582821 - 'Sphere Designer' does not reset correctly...
  + bgo#570353 - first time open of .svg file ignores the
    requested units
  + bgo#555777 - Export to MNG animation fails
  + bgo#577301 - Dithering with transparency is broken for
    "positioned" method
  + bgo#493778 - metadata plug-in crashes on some images
  + bgo#567466 - PNG comment not found if more than 1 tEXt chunks
  + bgo#585665 - Exporting to PSD with a blank text layer creates
    a corrupt file
  + bgo#586316 - Levels tool does not adjust output levels
    correctly if input levels are changed
  + bgo#569661 - Import from PDF throws errors when entering
    resolution in pixels per millimetre
  + bgo#567262 - Black pixels appear in "Spread" filter preview
  + bgo#554658 - Path Dialog: Path preview pics not to see
    constantly
  + bgo#167604 - gimp_gradient_get_color_at() may return
    out-of-bounds values
  + bgo#567393 - Rectangle select tool size shrinks to 0 if size
    is larger than the image and the up or down arrow
    is pressed
  + bgo#587543 - crash when invoking certain actions by keyboard
    shortcut
  + bgo#563029 - Closing maximized image doesn't restore document
    window size
  + bgo#585488 - Perspective transformation on a layer with a mask
    causes crash
  + bgo#586008 - GIMP crashes when right-click canceling a drawing
    action initiated outside layer boundaries
  + bgo#584345 - when printing, the number of copies should be
    reset to 1
  + bgo#557061 - Alpha to Logo
  + bgo#472644 - Rotate with clipping crops the whole layer
  + bgo#577575 - transform tool fills underlying extracted area
    wrongly
  + bgo#555738 - Image display is wrong after undoing canvas size
  + bgo#577024 - help-browser plugin crashes when used with webkit
    1.1.3
  + bgo#555025 - Action GEGL box widgets weirdness
- Drop gimp-gegl-babl-versions-check.patch: fixed upstream.
* Thu Jul 30 2009 vuntz@novell.com
- Add a Supplements between gimp and gimp-help to get the
  help-browser package automatically installed.
- Update descriptions of packages.
* Fri Jul 24 2009 beineri@opensuse.org
- Split off gnome-help-browser sub-package to save 4MB libwebkit
  dependency on Live-CDs where gimp-help is not included.
- Only include latest ChangeLog.
* Thu Jun 11 2009 vuntz@novell.com
- Add gimp-gegl-babl-versions-check.patch to fix the code used to
  check the babl and gegl version. Taken from Fedora/upstream.
* Tue Mar 17 2009 mboman@suse.de
- Update to version 2.6.6:
  + bgo#571117 - lcms plug-in crashes on broken profile
  + bgo#575154 - changing the help browser preference may not work
  + bgo#573542 - blur plugin: bug in the first line
  + bgo#572403 - gimp-2.6 crashed with SIGSEGV in
    IA__g_object_get()
  + bgo#573695 - 1-bit white background saved as PBM becomes all
    black
  + bgo#573488 - Small bug in Filter>Distorts>Ripple
  + bgo#572156 - top left pixel position/coordinate is not 0,0 but
    1,1
  + bgo#472644 - Rotate with clipping crops the whole layer
  + Translation updates
- Remove glibc-devel from Requires in -devel package
- Use py_requires.
- Remove gimp-enable-gtk-deprecated.patch: unneeded now.
* Tue Feb 17 2009 vuntz@novell.com
- Remove some BuildRequires:
  + libcurl-devel: not needed since we have gio
  + gnome-keyring-devel, gnome-vfs2-devel, libgnomeui-devel: not
    needed either since we have gio
- Fix Provides/Obsoletes for gimp-doc in devel package.
* Mon Feb 16 2009 mboman@suse.de
- Update to version 2.6.5:
  + bgo#571628 - Scaling image to 25%% turn background from white
    to grey
  + bgo#567840 - GIMP's GtkScaleButton conflicts with GTK's
  + bgo#569043 - GEGL tool - missing Operation Settings for all
    sub-tools
  + bgo#568890 - don't rely on GtkAction implementation details
  + bgo#568909 - wrong RGB values for color names in
    libgimpcolor/gimprgb-parse.c
  + bgo#568839 - wrong hex RGB value for the color names slategrey
    and slategray
  + bgo#559408 - Brushes dragged to the image window look strange
  + bgo#563337 - Rectangle Select Tool does not allow 1:1 fixed
    ratio
  + bgo#568016 - Black pullout parameter of plug-in-newsprint has
    no effect
  + bgo#562818 - First image opened in GIMP offset
  + bgo#562213 - Align Tool doesn't work properly if it is the
    active tool at startup
  + Translation updates
- Add gimp-enable-gtk-deprecated.patch due to using deprecated
  API call gtk_widget_get_action. Upstream is working on it so
  could probably be removed with the next version update
- Merge gtk-doc from -doc to -devel
- Fix BuildRequires according to what's in configure.ac:
  * Add: babl-devel, cairo-devel, fontconfig-devel, glib2-devel,
    gnome-keyring-devel, gnome-vfs2-devel, gtk2-devel,
    libcurl-devel, libpng-devel, pango-devel,
    xorg-x11-libXfixes-devel
  * Remove: BuildRequires: alsa-devel, cups, cups-devel,
    curl-devel, gnome-common, gnutls-devel, gtk-doc,
    libgimpprint, libgimpprint-devel, libglade2-devel,
    libgnomeprintui-devel, libgtkhtml-devel,
    libwnck-devel, perl-XML-Parser, postfix,
    python-devel, slang-devel
* Tue Feb 10 2009 vuntz@novell.com
- Remove non-upstream translations: they'll get out-of-date.
* Mon Jan 19 2009 crrodriguez@suse.de
- remove "la" files [BNC#357465]
* Sat Jan  3 2009 mboman@suse.de
- Update to version 2.6.4:
  + bgo#565223 - Perspective transformation jagged edges / comb effect
  + bgo#563985 - jpg save dialog: "cancel" is treated like "commit"
    for settings
  + bgo#564087 - Using clone tool on a layer with a part out of canvas
    causes crashes
  + bgo#564593 - crash when the drawable is changed while a color tool
    is active
  + bgo#564869 - GIMP crashes on selecting Tools->GEGL operation
  + bgo#565138 - python-fu-foggify does not check if image is in rgb mode
  + bgo#563130 - Hue selection mode does not cross the 0-360 degrees line
  + bgo#563179 - Scrollbars not resized when we extend the canvas size
  + bgo#562459 - PF_PALETTE: 'TypeError' when used in a plugin that is
    registered in <Image>
  + bgo#562427 - Compilation with --as-needed
  + bgo#562386 - PF_SLIDER and PF_SPINNER 'Step' values do not change
    consistently...
  + bgo#562366 - Default image dimensions are not correctly
    transferred in the file/new dialog box
  + bgo#561899 - GIMP can't save to mounted filesystem if file exists
  + Translation updates
* Mon Dec 29 2008 mboman@suse.de
- Update to version 2.6.3:
  + bgo#558454 - Plugin Map Color Range disappears from GIMP
  + bgo#559239 - Error while loading psd-data
  + bgo#560903 - Explicit zooming with e.g. '1' should handle
    zoom-focus better
  + bgo#560245 - Zoom selection always centered in the Navigation tab
  + bgo#559490 - Wrong lang tags for 'no'
  + bgo#559292 - SOTA Chrome cannot accept different textures
  + bgo#560375 - Clearing an already empty document history crashes GIMP
  + bgo#559580 - Image windows need better default locations
  + bgo#560283 - "Scale image..." causes distortion around edges
  + bgo#559716 - Changing crop size in Crop Tool Options can make UI
    unresponsive
  + bgo#558549 - Stroking a single-point path with a paint tool
    crashes GIMP
  + bgo#559015 - Move tool gives bad information about px moved
  + bgo#558660 - help behavior for locales without manual translation
  + Translation updates
- Remove gimp-help-fallback-en.patch. Fixed upstream
* Fri Dec 19 2008 mauro@suse.de
- Added hu-po.tar.bz2 to fix bnc#460663
  + Updated hungarian translation.
* Mon Nov  3 2008 sbrabec@suse.cz
- If help translation does not exist, fallback to English
  (bgo#558660).
* Fri Oct 31 2008 sbrabec@suse.cz
- Updated to version 2.6.2:
  * scaling speed improved
  * several crash, bug and regression against 2.4 fixes
  * translation updates
  * See NEWS for more
* Fri Oct 10 2008 sbrabec@suse.cz
- Updated to version 2.6.1:
  * 10 important crash and bug fixes
  * translation updates
  * See NEWS for more
* Mon Oct  6 2008 sbrabec@suse.cz
- Conflict with other branding providers (FATE#304881, bnc#429324).
* Thu Oct  2 2008 sbrabec@suse.cz
- Updated to version 2.6.0, the new stable branch:
  * depends on GEGL and uses it optionally in some color operations
  * UI refactoring
  * many improvements and new features
  * See NEWS for details.
* Thu Sep  4 2008 sbrabec@suse.cz
- Recommend gimp-2.0-scanner-plugin (bnc#422558).
* Fri Aug 22 2008 sbrabec@suse.cz
- Updated to version 2.4.7:
  * python binding fixes
  * fixed memory leak
  * bug fixes
  * translation updates
  * See NEWS for details.
* Wed Jul 16 2008 sbrabec@suse.cz
- Updated to version 2.4.6:
  * many fixes
  * translation updates
  * See NEWS for details.
* Tue Apr 15 2008 sbrabec@suse.cz
- Fixed dependencies of the branding package.
* Mon Apr 14 2008 sbrabec@suse.cz
- Use packageand form of branding supplement.
* Thu Mar 27 2008 sbrabec@suse.cz
- Added support for vendor branding (bnc#372091).
* Mon Mar  3 2008 sbrabec@suse.cz
- Updated to version 2.4.5:
  * many fixes
  * many corrections
  * translation updates
  * See NEWS for details.
* Wed Jan 30 2008 sbrabec@suse.cz
- Split plugins requiring python-gtk into a separate package
  (bnc#339862).
* Fri Dec  7 2007 sbrabec@suse.cz
- Removed gutenprint from BuildRequires (#245683#c23).
- Require python-gtk (#339862).
* Wed Oct 24 2007 sbrabec@suse.cz
- Updated to version 2.4.0:
  * further improved the rectangle select and crop tools
  * allow to mark out-of-gamut colors when doing a soft proof
  * bug fixes
- Package renamed from gimp-unstable to gimp.
* Thu Oct 11 2007 sbrabec@suse.cz
- poppler devel package names prepended by "lib".
* Mon Oct  8 2007 sbrabec@suse.cz
-  Use binding specific poppler devel package.
* Mon Sep 24 2007 stbinner@suse.de
- update to GIMP 2.3 Release Candidate 3 (#327516)
  * Changes in GIMP 2.4.0-rc3:
  - use the new format for storing recently used files
  - added conversion options to the color profile conversion plug-in
  - allow to disable the toolbox menu on all platforms
  - further improved handling of the JPEG settings
  - switch tabs when hovering over them
  - added a PDB function to remove the alpha channel from a layer
  - plug-in previews remember the state of the Preview checkbox
  - allow to grow the image/layer using the Crop tool
  * Changes in GIMP 2.4.0-rc2:
  - more improvements and bug fixes in the rectangle tools
  - antialias the display for zoom levels between 100%% and 200%%
  - fix zoomed-out display problems
  - improve handling of JPEG settings
  - fix script-fu error reporting
  - on OS X, get rid of menubars in windows and use the global menubar
  - fix plug-ins using GimpZoomPreview
  - throw properly catchable exceptions from foreign script-fu function
    (like PDB wrappers)
  * Changes in GIMP 2.4.0-rc1:
  - further improvement to the Print plug-in
  - completed the color management functionality for 2.4
  - store JPEG setting with the image and use them when saving as JPEG
  - further improved the rectangle tools, in particular handling of the
    fixed aspect ratio
  - added color profile selector widget
  - further improved the display quality for zoomed-out views
* Tue Sep 11 2007 stbinner@suse.de
- add Conflict with gimp-lang (#307289)
* Mon Jul 30 2007 maw@suse.de
- Update to version 2.3.19:
  + support long layer names in PSD files
  + improved EXIF handling in the JPEG file plug-in
  + added control for the playback speed in the Animation Playback plug-in
  + avoid needless image preview invalidation
  + allow to edit the image comment in the Image Properties dialog
  + further improved rectangle tools
  + made JPEG save parameters user-configurable
  + avoid color conversions between identical ICC color profiles
  + improved Print plug-in
  + improved loading and saving of indexed TGA images
  + temporarily show the hidden image statusbar while the progress is active
  + added support for loading .abr v6 Photoshop brushes
  + improved usability of color scales
  + improved display quality of zoomed-out image view
  + improved import of multi-page TIFF files
  + reduced rounding errors in Blur routines (core and plug-ins)
  + further improved parameter checks in the PDB
  + added support for loading .abr v2 Photoshop brushes
  + improved border behavior of the Blur tool
  + show the brush outline at the Clone tool's source position
  + added libgimpbase API to retrieve the user's Pictures folder
  + add a shortcut to the user's Pictures folder to the file-chooser dialog
  + improved the quality of the Motion Blur filter
  + save paths in TIFF files
  + let the Screenshot plug-in name the new layer after the window
  + use memory slices to reduce memory fragmentation
  + some code cleanup
  + lots of bug fixes
- Remove upstreamed gimp-psd-overflow.patch and gimp-sunras-overflow.patch.
* Wed Jul 18 2007 maw@suse.de
- Respin gimp-psd-overflow.patch (http://bugzilla.gnome.org/show_bug.cgi?id=456042
  and https://bugzilla.novell.com/show_bug.cgi?id=284288#c13).
* Tue Jul  3 2007 maw@suse.de
- Add gimp-psd-overflow.patch (#284288 and CVE-2007-2949), fixing
  a buffer overflow.
* Fri May 11 2007 pgajdos@suse.cz
- removed gnome-icon-theme from BuildRequires and Requires
  [#247450]
* Mon May  7 2007 sbrabec@suse.cz
  * Updated to version gimp-2.3.16:
  * XOR color configurable as a workaround for broken drivers
  * keyboard shortcuts can assign to procedures without menu entry
  * configurable height of the preview area in data editors
  * improved file detection in TGA plug-in
  * improved brush scaling code, now also scales up
  * converted standard pixmap brushes to parametric ones
  * improved zoom tool behavior
  * D-Bus methods have a return value indicating success or failure
  * added more menu tooltips
  * procedures can request the display ID they are called from
  * depend on GTK+ >= 2.10.6
  * filename passed on the command-line can open new image
  * various optimizations, bug fixes and code cleanup
* Fri May  4 2007 sbrabec@suse.cz
- Fixed buffer overflow in sunras plugin (#270506, GNOME#433902,
  CVE-2007-2356).
* Wed Apr  4 2007 sbrabec@suse.cz
- Updated to version gimp-2.3.15:
  * Fixes, improvements, UI and API changes. See NEWS for more.
* Thu Mar  8 2007 sbrabec@suse.cz
- Removed obsolete hicolor icon symlink (#248676).
* Wed Mar  7 2007 pgajdos@suse.cz
- fixed 'warning: subscript out of range' (#231161)
- subscript-outrng.patch
* Tue Feb 27 2007 dmueller@suse.de
- adjust buildrequires: libexif -> libexif-devel
* Wed Jan  3 2007 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Thu Sep 14 2006 sbrabec@suse.cz
- Updated to version 2.3.11:
  * Many new features, see
    /usr/share/doc/packages/gimp-unstable/NEWS for more.
  * Many bug fixes and code cleanup.
- Removed dcraw hack.
* Wed Aug 16 2006 cthiel@suse.de
- buildrequire python-gtk-devel instead of python-gtk
* Fri Jul 28 2006 sbrabec@suse.cz
- Fixed buffer overflow in xcf_load_vector (CVE-2006-3404,
  [#190901], GNOME#346742).
* Thu Jun 29 2006 nadvornik@suse.cz
- do not use deprecated libpng functions
* Wed Feb 15 2006 stbinner@suse.de
- use just "Gimp" as name, don't duplicate GenericName description
* Fri Feb 10 2006 sbrabec@suse.cz
- Updated to version 2.3.7.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan  5 2006 sbrabec@suse.cz
- Updated to version 2.3.6.
- Enabled parallel build.
* Tue Jan  3 2006 sbrabec@suse.cz
- Suggest AdobeICCProfiles.
* Mon Nov 21 2005 sbrabec@suse.cz
- Moved gimptool to -devel subpackage.
- Provide gimp symlink.
* Tue Nov  8 2005 sbrabec@suse.cz
- Build with strict aliasing.
- Fixed random return value.
* Mon Nov  7 2005 sbrabec@suse.cz
- Updated to version 2.3.5.
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Tue Sep 27 2005 sbrabec@suse.cz
- Updated to version 2.3.4.
* Mon Aug 15 2005 sbrabec@suse.cz
- Provide gimp-2.0 virtual.
* Wed Aug 10 2005 sbrabec@suse.cz
- Updated to version 2.3.3.
* Thu Aug  4 2005 sbrabec@suse.cz
- Do not self-conflict.
* Fri Jul 15 2005 sbrabec@suse.cz
- Provide and conflict with gimp.
* Tue Jul 12 2005 sbrabec@suse.cz
- Fixed MMX patch reject.
* Mon Jul 11 2005 sbrabec@suse.cz
- Created SuSE package for unstable branch.
- Updated to version 2.3.2.
- Removed unneeded static modules and .la files for modules.
* Thu Jul  7 2005 gekker@suse.de
- Fix use of uninitialized variables
- Fix to work with -D_FORTIFY_SOURCE=2
* Tue Jun  7 2005 sbrabec@suse.cz
- Fixed multiple processors option.
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Wed May 18 2005 sbrabec@suse.cz
- Updated to version 2.2.7.
* Mon May  9 2005 ro@suse.de
- use -mmmx and -msse to compile asm-code for these extensions
* Tue Apr 12 2005 sbrabec@suse.cz
- Updated to version 2.2.6.
* Wed Apr  6 2005 sbrabec@suse.cz
- Fixed incomplete array element type.
* Mon Feb 28 2005 sbrabec@suse.cz
- Updated to version 2.2.4.
* Mon Jan 24 2005 sbrabec@suse.cz
- Updated to version 2.2.3.
* Mon Jan 17 2005 sbrabec@suse.cz
- Updated to version 2.2.2.
* Thu Jan  6 2005 ro@suse.de
- postfix is in neededforbuild, so add "-sendmail" for PLUS
* Thu Jan  6 2005 sbrabec@suse.cz
- Updated to version 2.2.1.
* Tue Oct 26 2004 mmj@suse.de
- locale rename no to nb
* Wed Sep 22 2004 adrian@suse.de
- add MimeTypes line to desktop file. Gimp does support .xcf files now
* Mon Aug 30 2004 rml@suse.de
- upgrade to gimp 2.0.4 (Ximian bug #64677)
* Fri Aug 27 2004 shprasad@suse.de
- Fixes bug #63425
  Fixes GIMP Crash at the time of acquiring screen-shot and select
  extension type as png
- Partially fixes bug #63420
  Doesn't allow to crash.
* Mon Aug 16 2004 shprasad@suse.de
- Fixes bug #63006.
  Added the gtk-file-chooser dialog to Open/Save a file.
* Thu Jun 17 2004 sbrabec@suse.cz
- Updated to version 2.0.2.
* Fri Jun  4 2004 sbrabec@suse.cz
- Updated to bugfix version 2.0.1.
* Tue May 25 2004 ro@suse.de
- added libcroco to neededforbuild
* Wed May 19 2004 sbrabec@suse.cz
- German translation update from Karl Eichwalder.
* Fri May  7 2004 sbrabec@suse.cz
- Better fix (fork() instead of fail wrapper) of gimp-remote bug
  (#38512), backported from gimp-2.0.1.
  http://bugzilla.gnome.org/show_bug.cgi?id=139158
* Wed Apr  7 2004 sbrabec@suse.cz
- Work around of gimp-remote bug (#38512).
  http://bugzilla.gnome.org/show_bug.cgi?id=139158
* Wed Apr  7 2004 sbrabec@suse.cz
- Fixed WMF plugin (#38582).
* Thu Mar 25 2004 mmj@suse.de
- Add postfix to # neededforbuild
* Wed Mar 24 2004 hhetter@suse.de
- updated to version 2.0.0 finally
* Mon Mar 22 2004 sbrabec@suse.cz
- Provide gimp2-devel.
* Mon Mar 22 2004 sbrabec@suse.cz
- Updated to version 2.0rc1.
- GIMP GNOME MIME info files linked to proper place,
- Obsolete gimp2-devel, too.
* Fri Mar  5 2004 hhetter@suse.de
- updated to 2.0pre4
- removed gimp-po-de.patch, it's upstream
- adapted tiff_no_lzw patch
* Tue Mar  2 2004 sbrabec@suse.cz
- Symlink binaries for convenience.
* Tue Mar  2 2004 sbrabec@suse.cz
- German typo fix (bug #34349).
* Fri Feb 27 2004 schwab@suse.de
- Fix broken configure check.
* Fri Feb 20 2004 sbrabec@suse.cz
- Provide and obsolete gimp2.
* Thu Feb 19 2004 sbrabec@suse.cz
- Package renamed to gimp.
* Thu Feb  5 2004 hhetter@suse.de
- updated to version 2.0pre3
- remove desktop file patch, it's called gimp2 now
* Thu Jan 29 2004 hhetter@suse.de
- updated to version 2.0pre2
* Tue Jan 27 2004 hhetter@suse.de
- updated to version 2.0pre1
- renew patch for LZW deactivation
* Mon Oct 20 2003 sbrabec@suse.cz
- Updated to version 1.3.21. Fixes screenshot bug (#32288).
- Build SVG plug-in.
- Clean-up of neededforbuild.
* Wed Oct 15 2003 ro@suse.de
- run full autoreconf
* Thu Sep 18 2003 sbrabec@suse.cz
- Do not show LZW in tiff save dialog at all (bug #29849).
* Mon Sep 15 2003 hhetter@suse.de
- name label "Gimp 1.3" in desktop file (Bug Id #30841)
* Mon Sep  8 2003 sbrabec@suse.cz
- Updated to version 1.3.20.
* Thu Aug 28 2003 sbrabec@suse.cz
- Updated to version 1.3.19.
- Enabled EXIF support.
* Sat Aug 16 2003 adrian@suse.de
- install desktop file
* Thu Aug 14 2003 sbrabec@suse.cz
- Updated to version 1.3.18.
* Mon Aug  4 2003 sbrabec@suse.cz
- Updated to version 1.3.17.
* Fri Jul 25 2003 hhetter@suse.de
- fix build
* Thu Jun 26 2003 sbrabec@suse.cz
- Updated to version 1.3.15.
- Used system libgimpprint.
* Thu Jun 19 2003 ro@suse.de
- added directories to filelist
* Tue Jun 10 2003 sbrabec@suse.cz
- Initial SuSE version of GTK2 port.
